@@ -24,7 +24,7 @@
 #include "skycomponents/starcomponent.h"
 #include "skycomponents/skymapcomposite.h"
 
-#include <kmessagebox.h>
+#include <KMessageBox>
 
 #include <QSortFilterProxyModel>
 #include <QStringListModel>
@@ -33,31 +33,47 @@
 FindDialogUI::FindDialogUI( QWidget *parent ) : QFrame( parent ) {
     setupUi( this );
 
-    FilterType->addItem( i18n ("Any") );
-    FilterType->addItem( i18n ("Stars") );
-    FilterType->addItem( i18n ("Solar System") );
-    FilterType->addItem( i18n ("Open Clusters") );
-    FilterType->addItem( i18n ("Globular Clusters") );
-    FilterType->addItem( i18n ("Gaseous Nebulae") );
-    FilterType->addItem( i18n ("Planetary Nebulae") );
-    FilterType->addItem( i18n ("Galaxies") );
-    FilterType->addItem( i18n ("Comets") );
-    FilterType->addItem( i18n ("Asteroids") );
-    FilterType->addItem( i18n ("Constellations") );
-    FilterType->addItem( i18n ("Supernovae") );
+    FilterType->addItem( xi18n ("Any") );
+    FilterType->addItem( xi18n ("Stars") );
+    FilterType->addItem( xi18n ("Solar System") );
+    FilterType->addItem( xi18n ("Open Clusters") );
+    FilterType->addItem( xi18n ("Globular Clusters") );
+    FilterType->addItem( xi18n ("Gaseous Nebulae") );
+    FilterType->addItem( xi18n ("Planetary Nebulae") );
+    FilterType->addItem( xi18n ("Galaxies") );
+    FilterType->addItem( xi18n ("Comets") );
+    FilterType->addItem( xi18n ("Asteroids") );
+    FilterType->addItem( xi18n ("Constellations") );
+    FilterType->addItem( xi18n ("Supernovae") );
+    FilterType->addItem( xi18n ("Satellites") );
 
     SearchList->setMinimumWidth( 256 );
     SearchList->setMinimumHeight( 320 );
 }
 
 FindDialog::FindDialog( QWidget* parent ) :
-    KDialog( parent ),
+    QDialog( parent ),
     timer(0)
 {
     ui = new FindDialogUI( this );
-    setMainWidget( ui );
-    setCaption( i18n( "Find Object" ) );
-    setButtons( KDialog::Ok|KDialog::User1|KDialog::Cancel );
+
+    setWindowTitle( xi18n( "Find Object" ) );
+
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    mainLayout->addWidget(ui);
+    setLayout(mainLayout);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(accepted()), this, SLOT(slotOk()));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+
+    okB = buttonBox->button(QDialogButtonBox::Ok);
+
+    QPushButton *detailB = new QPushButton(xi18n("Details..."));
+    buttonBox->addButton(detailB, QDialogButtonBox::ActionRole);
+    connect(detailB, SIGNAL(clicked()), this, SLOT(slotDetails()));
+
     ui->FilterType->setCurrentIndex(0);  // show all types of objects
 
     fModel = new QStringListModel( this );
@@ -66,12 +82,8 @@ FindDialog::FindDialog( QWidget* parent ) :
     ui->SearchList->setModel( sortModel );
     sortModel->setSourceModel( fModel );
     ui->SearchList->setModel( sortModel );
-    setButtonText(KDialog::User1, i18n("Details..."));
 
     // Connect signals to slots
-    connect( this, SIGNAL( okClicked() ), this, SLOT( slotOk() ) );
-    connect( this, SIGNAL( cancelClicked() ), this, SLOT( reject() ) );
-    connect(this, SIGNAL(user1Clicked()), this, SLOT(slotDetails()));
     connect( ui->SearchBox, SIGNAL( textChanged( const QString & ) ), SLOT( enqueueSearch() ) );
     connect( ui->SearchBox, SIGNAL( returnPressed() ), SLOT( slotOk() ) );
     connect( ui->FilterType, SIGNAL( activated( int ) ), this, SLOT( enqueueSearch() ) );
@@ -96,8 +108,9 @@ void FindDialog::init() {
 }
 
 void FindDialog::initSelection() {
-    if ( sortModel->rowCount() <= 0 ) {
-        button( Ok )->setEnabled( false );
+    if ( sortModel->rowCount() <= 0 )
+    {
+        okB->setEnabled( false );
         return;
     }
 
@@ -107,26 +120,26 @@ void FindDialog::initSelection() {
         switch ( ui->FilterType->currentIndex() ) {
         case 0: //All objects, choose Andromeda galaxy
             {
-                QModelIndex qmi = fModel->index( fModel->stringList().indexOf( i18n("Andromeda Galaxy") ) );
+                QModelIndex qmi = fModel->index( fModel->stringList().indexOf( xi18n("Andromeda Galaxy") ) );
                 selectItem = sortModel->mapFromSource( qmi );
                 break;
             }
         case 1: //Stars, choose Aldebaran
             {
-                QModelIndex qmi = fModel->index( fModel->stringList().indexOf( i18n("Aldebaran") ) );
+                QModelIndex qmi = fModel->index( fModel->stringList().indexOf( xi18n("Aldebaran") ) );
                 selectItem = sortModel->mapFromSource( qmi );
                 break;
             }
         case 2: //Solar system or Asteroids, choose Aaltje
         case 9:
             {
-                QModelIndex qmi = fModel->index( fModel->stringList().indexOf( i18n("Aaltje") ) );
+                QModelIndex qmi = fModel->index( fModel->stringList().indexOf( xi18n("Aaltje") ) );
                 selectItem = sortModel->mapFromSource( qmi );
                 break;
             }
         case 8: //Comets, choose 'Aarseth-Brewington (1989 W1)'
             {
-                QModelIndex qmi = fModel->index( fModel->stringList().indexOf( i18n("Aarseth-Brewington (1989 W1)") ) );
+                QModelIndex qmi = fModel->index( fModel->stringList().indexOf( xi18n("Aarseth-Brewington (1989 W1)") ) );
                 selectItem = sortModel->mapFromSource( qmi );
                 break;
             }
@@ -137,7 +150,8 @@ void FindDialog::initSelection() {
             ui->SearchList->selectionModel()->select( selectItem, QItemSelectionModel::ClearAndSelect );
             ui->SearchList->scrollTo( selectItem );
             ui->SearchList->setCurrentIndex( selectItem );
-            button( Ok )->setEnabled( true );
+
+            okB->setEnabled(true);
         }
     }
 
@@ -171,7 +185,7 @@ void FindDialog::filterByType() {
             ssObjects += data->skyComposite()->objectNames( SkyObject::COMET );
             ssObjects += data->skyComposite()->objectNames( SkyObject::ASTEROID );
             ssObjects += data->skyComposite()->objectNames( SkyObject::MOON );
-            ssObjects += i18n("Sun");
+            ssObjects += xi18n("Sun");
             fModel->setStringList( ssObjects );
             break;
         }
@@ -202,6 +216,9 @@ void FindDialog::filterByType() {
     case 11: //Supernovae
         fModel->setStringList( data->skyComposite()->objectNames( SkyObject::SUPERNOVA ) );
         break;
+    case 12: //Satellites
+        fModel->setStringList( data->skyComposite()->objectNames( SkyObject::SATELLITE ) );
+        break;
     }
 }
 
@@ -225,7 +242,8 @@ void FindDialog::filterList() {
                 ui->SearchList->selectionModel()->select( selectItem, QItemSelectionModel::ClearAndSelect );
                 ui->SearchList->scrollTo( selectItem );
                 ui->SearchList->setCurrentIndex( selectItem );
-                button( Ok )->setEnabled( true );
+
+                okB->setEnabled(true);
             }
         }
     }
@@ -300,8 +318,8 @@ void FindDialog::slotOk() {
     }
     selObj = selectedObject();
     if ( selObj == 0 ) {
-        QString message = i18n( "No object named %1 found.", ui->SearchBox->text() );
-        KMessageBox::sorry( 0, message, i18n( "Bad object name" ) );
+        QString message = xi18n( "No object named %1 found.", ui->SearchBox->text() );
+        KMessageBox::sorry( 0, message, xi18n( "Bad object name" ) );
     } else {
         accept();
     }
@@ -343,4 +361,4 @@ void FindDialog::slotDetails()
 
 }
 
-#include "finddialog.moc"
+
