@@ -43,13 +43,18 @@ class KDirWatch;
  * - Auto guiding with support for automatic dithering between exposures and support for Adaptive Optics devices in addition to traditional guiders.
  * - Powerful sequence queue for batch capture of images with optional prefixes, timestamps, filter wheel selection, and much more!
  * - Export and import sequence queue sets as Ekos Sequence Queue (.esq) files.
+ * - Center the telescope anywhere in a captured FITS image or any FITS with World Coordinate System (WCS) header.
+ * - Automatic flat field capture, just set the desired ADU and let Ekos does the rest!
  * - Automatic abort and resumption of exposure tasks if guiding errors exceed a user-configurable value.
  * - Support for dome slaving.
  * - Complete integration with KStars Observation Planner and SkyMap
  * - Integrate with all INDI native devices.
  * - Powerful scripting capabilities via \ref EkosDBusInterface "DBus."
+ *
+ * The primary class is EkosManager. It handles startup and shutdown of local and remote INDI devices, manages and orchesterates the various Ekos modules, and provides advanced DBus
+ * interface to enable unattended scripting.
 *@author Jasem Mutlaq
- *@version 1.0
+ *@version 1.1
  */
 namespace Ekos
 {
@@ -134,7 +139,13 @@ class SequenceJob : public QObject
     void setCurrentTemperature(double value);
 
     double getTargetTemperature() const;
-    void setTargetTemperature(double value);
+    void setTargetTemperature(double value);    
+
+    double getTargetADU() const;
+    void setTargetADU(double value);
+
+    int getCaptureRetires() const;
+    void setCaptureRetires(int value);
 
 signals:
     void prepareComplete();
@@ -158,12 +169,13 @@ private:
     int x,y,w,h;
     QString prefix;
     int count;
-    int delay;
+    int delay;    
     bool isoMode;
     bool preview;
     bool showFITS;
     bool filterReady, temperatureReady;
     int isoIndex;
+    int captureRetires;
     unsigned int completed;
     double exposeLeft;
     double currentTemperature, targetTemperature;
@@ -176,6 +188,7 @@ private:
 
     JOBStatus status;
 
+    double targetADU;
 };
 
 /**
@@ -220,6 +233,17 @@ public:
      */
     Q_SCRIPTABLE bool setFilter(QString device, int filterSlot);
 
+    /** DBUS interface function.
+     * Aborts any current jobs and remove all sequence queue jobs.
+     */
+    Q_SCRIPTABLE Q_NOREPLY void clearSequenceQueue();
+
+    /** DBUS interface function.
+     * Returns the overall sequence queue status. If there are no jobs pending, it returns "Invalid". If all jobs are idle, it returns "Idle". If all jobs are complete, it returns "Complete". If one or more jobs are aborted
+     * it returns "Aborted". If one or more jobs have errors, it returns "Error". If any jobs is under progress, returns "Running".
+     */
+    Q_SCRIPTABLE QString getSequenceQueueStatus();
+
     /** DBUS interface function.
      * Loads the Ekos Sequence Queue file in the Sequence Queue. Jobs are appended to existing jobs.
      * @param fileURL full URL of the filename
@@ -332,8 +356,12 @@ public slots:
     void checkPreview(bool enable);
     void updateCCDTemperature(double value);
     void setTemperature();
+    void setDirty();
+
+    void checkFrameType(int index);
+    void resetFrame();
     void updateAutofocusStatus(bool status, double HFR);
-    void updateCaptureProgress(ISD::CCDChip *tChip, double value);
+    void updateCaptureProgress(ISD::CCDChip *tChip, double value, IPState state);
     void checkSeqBoundary(const QString &path);
 
     void saveFITSDirectory();
@@ -372,6 +400,7 @@ private:
     bool processJobInfo(XMLEle *root);    
     bool saveSequenceQueue(const QString &path);
     void constructPrefix(QString &imagePrefix);
+    double setCurrentADU(double value);
 
     /* Meridian Flip */
     bool checkMeridianFlip();
@@ -436,10 +465,12 @@ private:
     double initialRA;
     bool resumeAlignmentAfterFlip;
     bool resumeGuidingAfterFlip;
-
     MFStage meridianFlipStage;
 
-
+    // Flat field automation
+    double ExpRaw1, ExpRaw2;
+    double ADURaw1, ADURaw2;
+    double ADUSlope;
 
 };
 
