@@ -122,6 +122,7 @@ public:
     double getMedian() { return stats.median;}
     void setBPP(int value) { stats.bitpix = value;}
     int getBPP() { return stats.bitpix; }
+    double getADUPercentage();
 
     // Star detection
     int getDetectedStars() { return starCenters.count(); }
@@ -133,6 +134,7 @@ public:
     // Half Flux Radius
     Edge * getMaxHFRStar() { return maxHFRStar;}
     double getHFR(HFRType type=HFR_AVERAGE);
+    double getHFR(int x, int y);
 
     // FITS Mode (Normal, Guide, Focus..etc).
     FITSMode getMode() { return mode;}
