@@ -97,7 +97,7 @@ DriverManager * DriverManager::Instance()
 }
 
 DriverManager::DriverManager()
-        : QDialog( KStars::Instance() )
+        : QDialog( /*KStars::Instance()*/ )
 {
 
     currentPort = Options::serverPortStart().toInt()-1;
@@ -1435,6 +1435,17 @@ DriverInfo * DriverManager::findDriverByLabel(const QString &label)
     return NULL;
 }
 
+DriverInfo * DriverManager::findDriverByExec(const QString &exec)
+{
+    foreach(DriverInfo *dv, driversList)
+    {
+        if (dv->getDriver() == exec)
+            return dv;
+    }
+
+    return NULL;
+}
+
 QString DriverManager::getUniqueDeviceLabel(const QString &label)
 {
     int nset=0;
@@ -1447,8 +1458,8 @@ QString DriverManager::getUniqueDeviceLabel(const QString &label)
                 nset++;
         }
 
-  if (nset > 1)
-      uniqueLabel = QString("%1 %2").arg(label).arg(nset);
+  if (nset > 0)
+      uniqueLabel = QString("%1 %2").arg(label).arg(nset+1);
 
   return uniqueLabel;
 }
