@@ -22,18 +22,17 @@
 #include <QSplitter>
 
 #include <KLed>
-#include <KLineEdit>
-#include <KPushButton>
-#include <KLocale>
+#include <QLocale>
 #include <KMessageBox>
-#include <KDebug>
-#include <KComboBox>
-#include <KNumInput>
-#include <KDialog>
-#include <KTabWidget>
+#include <QDebug>
+#include <QComboBox>
+#include <QDialog>
+#include <QTabWidget>
 
 #include <basedevice.h>
 
+#include "fitsviewer/fitsviewer.h"
+
 #include "kstars.h"
 #include "indidevice.h"
 #include "guimanager.h"
@@ -55,21 +54,21 @@ GUIManager * GUIManager::Instance()
 GUIManager::GUIManager(QWidget *parent) : QWidget(parent, Qt::Window)
 {
 
-    //ksw = (KStars *) parent;
+    genericViewer = NULL;
 
     mainLayout    = new QVBoxLayout(this);
     mainLayout->setMargin(10);
     mainLayout->setSpacing(10);
 
-    mainTabWidget = new KTabWidget(this);
+    mainTabWidget = new QTabWidget(this);
 
     mainLayout->addWidget(mainTabWidget);
 
-    setWindowTitle(i18n("INDI Control Panel"));
+    setWindowTitle(xi18n("INDI Control Panel"));
     setAttribute(Qt::WA_ShowModal, false);
 
-    clearB      = new QPushButton(i18n("Clear"));
-    closeB      = new QPushButton(i18n("Close"));
+    clearB      = new QPushButton(xi18n("Clear"));
+    closeB      = new QPushButton(xi18n("Close"));
 
     QHBoxLayout *buttonLayout = new QHBoxLayout;
     buttonLayout->insertStretch(0);
@@ -92,7 +91,7 @@ void GUIManager::updateStatus()
 {
     if (clients.size() == 0)
     {
-        KMessageBox::error(0, i18n("No INDI devices currently running. To run devices, please select devices from the Device Manager in the devices menu."));
+        KMessageBox::error(0, xi18n("No INDI devices currently running. To run devices, please select devices from the Device Manager in the devices menu."));
         return;
     }
 
@@ -220,4 +219,13 @@ void GUIManager::buildDevice(DeviceInfo *di)
 }
 
 
-#include "guimanager.moc"
+FITSViewer * GUIManager::getGenericFITSViewer()
+{
+    if (genericViewer == NULL)
+    {
+        genericViewer = new FITSViewer(KStars::Instance());
+        genericViewer->setAttribute(Qt::WA_DeleteOnClose);
+    }
+
+    return genericViewer;
+}
