@@ -35,8 +35,15 @@ const int MAX_FILENAME_LEN = 1024;
 namespace ISD
 {
 
-
+#ifdef INDI_VERSION_MAJOR
+#if (INDI_VERSION_MAJOR >= 1 && INDI_VERSION_MINOR >= 1)
+GDSetCommand::GDSetCommand(INDI_PROPERTY_TYPE inPropertyType, const QString &inProperty, const QString &inElement, QVariant qValue, QObject *parent) : QObject(parent)
+#else
 GDSetCommand::GDSetCommand(INDI_TYPE inPropertyType, const QString &inProperty, const QString &inElement, QVariant qValue, QObject *parent) : QObject(parent)
+#endif
+#else
+GDSetCommand::GDSetCommand(INDI_TYPE inPropertyType, const QString &inProperty, const QString &inElement, QVariant qValue, QObject *parent) : QObject(parent)
+#endif
 {
     propType     = inPropertyType;
     indiProperty = inProperty;
@@ -143,11 +150,27 @@ void GenericDevice::registerProperty(INDI::Property *prop)
                 clientManager->sendNewText(prop->getText());
             }
         }
-        else if (driverInfo->getType() == KSTARS_AUXILIARY || QString(prop->getDeviceName()) == Options::remoteAuxName())
+        else if (driverInfo->getAuxInfo().value("AUX#", 0).toInt() == 1 || QString(prop->getDeviceName()) == Options::remoteAux1Name())
         {
-            if (Options::auxPort().isEmpty() == false)
+            if (Options::aux1Port().isEmpty() == false)
             {
-                IUSaveText(tp, Options::auxPort().toLatin1().constData());
+                IUSaveText(tp, Options::aux1Port().toLatin1().constData());
+                clientManager->sendNewText(prop->getText());
+            }
+        }
+        else if (driverInfo->getAuxInfo().value("AUX#", 0).toInt() == 2 || QString(prop->getDeviceName()) == Options::remoteAux2Name())
+        {
+            if (Options::aux2Port().isEmpty() == false)
+            {
+                IUSaveText(tp, Options::aux2Port().toLatin1().constData());
+                clientManager->sendNewText(prop->getText());
+            }
+        }
+        else if (driverInfo->getAuxInfo().value("AUX#", 0).toInt() == 3 || QString(prop->getDeviceName()) == Options::remoteAux3Name())
+        {
+            if (Options::aux3Port().isEmpty() == false)
+            {
+                IUSaveText(tp, Options::aux3Port().toLatin1().constData());
                 clientManager->sendNewText(prop->getText());
             }
         }
@@ -272,6 +295,11 @@ void GenericDevice::processLight(ILightVectorProperty * lvp)
     INDI_UNUSED(lvp);
 }
 
+void GenericDevice::processMessage(int messageID)
+{
+   INDI_UNUSED(messageID);
+}
+
 void GenericDevice::processBLOB(IBLOB* bp)
 {
     QFile       *data_file = NULL;
@@ -690,6 +718,12 @@ void DeviceDecorator::processText(ITextVectorProperty *tvp)
     emit textUpdated(tvp);
 }
 
+void DeviceDecorator::processMessage(int messageID)
+{
+    interfacePtr->processMessage(messageID);
+    emit messageUpdated(messageID);
+}
+
 void DeviceDecorator::registerProperty(INDI::Property *prop)
 {
     interfacePtr->registerProperty(prop);
@@ -701,7 +735,6 @@ void DeviceDecorator::removeProperty(INDI::Property *prop)
     emit propertyDeleted(prop);
 }
 
-
 bool DeviceDecorator::setConfig(INDIConfig tConfig)
 {
     return interfacePtr->setConfig(tConfig);
