@@ -18,9 +18,9 @@
 #include "kspopupmenu.h"
 
 #include <QSignalMapper>
+#include <QWidgetAction>
 
-#include <KGlobal>
-#include <KLocale>
+#include <KLocalizedString>
 
 #include "kstars.h"
 #include "kstarsdata.h"
@@ -37,7 +37,7 @@
 
 #include <config-kstars.h>
 
-#ifdef HAVE_INDI_H
+#ifdef HAVE_INDI
 #include "indi/indilistener.h"
 #include "indi/guimanager.h"
 #include "indi/driverinfo.h"
@@ -55,7 +55,10 @@
 namespace {
     // Convert magnitude to string representation for QLabel
     QString magToStr(double m) {
-        return QString("%1<sup>m</sup>").arg(m, 0, 'f', 2);
+        if (m > -30 && m < 90)
+            return QString("%1<sup>m</sup>").arg(m, 0, 'f', 2);
+        else
+            return QString();
     }
 
     // Return object name
@@ -81,15 +84,15 @@ namespace {
         QTime t = o->riseSetTime( data->ut(), data->geo(), isRaise );
         if ( t.isValid() ) {
             //We can round to the nearest minute by simply adding 30 seconds to the time.
-            QString time = KGlobal::locale()->formatTime( t.addSecs(30) );
+            QString time = QLocale().toString( t.addSecs(30) );
             return isRaise ?
-                i18n ("Rise time: %1", time) :
-                i18nc("the time at which an object falls below the horizon", "Set time: %1" , time);
+                xi18n ("Rise time: %1", time) :
+                xi18nc("the time at which an object falls below the horizon", "Set time: %1" , time);
         }
         if( o->alt().Degrees() > 0 )
-            return isRaise ? i18n( "No rise time: Circumpolar" ) : i18n( "No set time: Circumpolar" );
+            return isRaise ? xi18n( "No rise time: Circumpolar" ) : xi18n( "No set time: Circumpolar" );
         else
-            return isRaise ? i18n( "No rise time: Never rises" ) : i18n( "No set time: Never rises" );
+            return isRaise ? xi18n( "No rise time: Never rises" ) : xi18n( "No set time: Never rises" );
     }
 
     // String representation for transit time for object
@@ -98,7 +101,7 @@ namespace {
         QTime t = o->transitTime( data->ut(), data->geo() );
         if ( t.isValid() )
             //We can round to the nearest minute by simply adding 30 seconds to the time.
-            return i18n( "Transit time: %1", KGlobal::locale()->formatTime( t.addSecs(30) ) );
+            return xi18n( "Transit time: %1", QLocale().toString( t.addSecs(30) ) );
         else
             return "--:--";
     }
@@ -107,7 +110,7 @@ namespace {
 
 
 KSPopupMenu::KSPopupMenu()
-    : KMenu( KStars::Instance() ), m_CurrentFlagIdx(-1), m_EditActionMapping(0), m_DeleteActionMapping(0)
+    : QMenu( KStars::Instance() ), m_CurrentFlagIdx(-1), m_EditActionMapping(0), m_DeleteActionMapping(0)
 {}
 
 KSPopupMenu::~KSPopupMenu()
@@ -126,9 +129,9 @@ void KSPopupMenu::createEmptyMenu( SkyPoint *nullObj ) {
     SkyObject o( SkyObject::TYPE_UNKNOWN, nullObj->ra(), nullObj->dec() );
     o.setAlt( nullObj->alt() );
     o.setAz( nullObj->az() );
-    initPopupMenu( &o, i18n( "Empty sky" ), QString(), QString(), false, false );
-    addAction( i18nc( "Sloan Digital Sky Survey", "Show SDSS Image" ), ks->map(), SLOT( slotSDSS() ) );
-    addAction( i18nc( "Digitized Sky Survey", "Show DSS Image" ),      ks->map(), SLOT( slotDSS()  ) );
+    initPopupMenu( &o, xi18n( "Empty sky" ), QString(), QString(), false, false );
+    addAction( xi18nc( "Sloan Digital Sky Survey", "Show SDSS Image" ), ks->map(), SLOT( slotSDSS() ) );
+    addAction( xi18nc( "Digitized Sky Survey", "Show DSS Image" ),      ks->map(), SLOT( slotDSS()  ) );
 }
 
 void KSPopupMenu::slotEditFlag() {
@@ -138,7 +141,7 @@ void KSPopupMenu::slotEditFlag() {
 }
 
 void KSPopupMenu::slotDeleteFlag() {
-    if ( m_CurrentFlagIdx != -1 ) { 
+    if ( m_CurrentFlagIdx != -1 ) {
         KStars::Instance()->map()->slotDeleteFlag( m_CurrentFlagIdx );
     }
 }
@@ -181,28 +184,28 @@ void KSPopupMenu::createStarMenu( StarObject *star ) {
             name = "Star";
         }
     }
-    initPopupMenu( star, name, i18n( "star" ), i18n("%1<sup>m</sup>, %2", star->mag(), star->sptype()) );
+    initPopupMenu( star, name, xi18n( "star" ), xi18n("%1<sup>m</sup>, %2", star->mag(), star->sptype()) );
     //If the star is named, add custom items to popup menu based on object's ImageList and InfoList
     if ( star->name() != "star" ) {
         addLinksToMenu( star );
     } else {
-        addAction( i18nc( "Sloan Digital Sky Survey", "Show SDSS Image" ), ks->map(), SLOT( slotSDSS() ) );
-        addAction( i18nc( "Digitized Sky Survey", "Show DSS Image" ), ks->map(), SLOT( slotDSS() ) );
+        addAction( xi18nc( "Sloan Digital Sky Survey", "Show SDSS Image" ), ks->map(), SLOT( slotSDSS() ) );
+        addAction( xi18nc( "Digitized Sky Survey", "Show DSS Image" ), ks->map(), SLOT( slotDSS() ) );
     }
 }
 
 void KSPopupMenu::createDeepSkyObjectMenu( DeepSkyObject *obj ) {
     QString name     = getObjectName(obj);
     QString typeName = obj->typeName();
-	// FIXME: information about angular sizes should be added.
-	QString info = magToStr( obj->mag() );
-	initPopupMenu( obj, name, typeName, info );
+    // FIXME: information about angular sizes should be added.
+    QString info = magToStr( obj->mag() );
+    initPopupMenu( obj, name, typeName, info );
     addLinksToMenu( obj );
 }
 
 void KSPopupMenu::createPlanetMenu( SkyObject *p ) {
     QString info = magToStr( p->mag() );
-	QString type = i18n("Solar system object");;
+    QString type = xi18n("Solar system object");;
     initPopupMenu( p, p->translatedName(), type, info);
     addLinksToMenu( p, false ); //don't offer DSS images for planets
 }
@@ -221,34 +224,34 @@ void KSPopupMenu::createSatelliteMenu( Satellite *satellite ) {
     range.setNum( satellite->range() );
 
     clear();
-    
+
     addFancyLabel( satellite->name() );
     addFancyLabel( satellite->id() );
-    addFancyLabel( i18n( "satellite" ) );
+    addFancyLabel( xi18n( "satellite" ) );
     addFancyLabel( KStarsData::Instance()->skyComposite()->getConstellationBoundary()->constellationName( satellite ) );
 
     addSeparator();
 
-    addFancyLabel( i18n( "Velocity: %1 km/s", velocity ), -2 );
-    addFancyLabel( i18n( "Altitude: %1 km", altitude ), -2 );
-    addFancyLabel( i18n( "Range: %1 km", range ), -2 );
+    addFancyLabel( xi18n( "Velocity: %1 km/s", velocity ), -2 );
+    addFancyLabel( xi18n( "Altitude: %1 km", altitude ), -2 );
+    addFancyLabel( xi18n( "Range: %1 km", range ), -2 );
 
     addSeparator();
 
     //Insert item for centering on object
-    addAction( i18n( "Center && Track" ), ks->map(), SLOT( slotCenter() ) );
+    addAction( xi18n( "Center && Track" ), ks->map(), SLOT( slotCenter() ) );
     //Insert item for measuring distances
     //FIXME: add key shortcut to menu items properly!
-    addAction( i18n( "Angular Distance To...            [" ), ks->map(),
+    addAction( xi18n( "Angular Distance To...            [" ), ks->map(),
                SLOT(slotBeginAngularDistance()) );
-    addAction( i18n( "Starhop from here to...            " ), ks->map(),
+    addAction( xi18n( "Starhop from here to...            " ), ks->map(),
                SLOT(slotBeginStarHop()) );
 
     //Insert "Add/Remove Label" item
     if ( ks->map()->isObjectLabeled( satellite ) )
-        addAction( i18n( "Remove Label" ), ks->map(), SLOT( slotRemoveObjectLabel() ) );
+        addAction( xi18n( "Remove Label" ), ks->map(), SLOT( slotRemoveObjectLabel() ) );
     else
-        addAction( i18n( "Attach Label" ), ks->map(), SLOT( slotAddObjectLabel() ) );
+        addAction( xi18n( "Attach Label" ), ks->map(), SLOT( slotAddObjectLabel() ) );
 }
 
 void KSPopupMenu::createSupernovaMenu(Supernova* supernova)
@@ -256,18 +259,19 @@ void KSPopupMenu::createSupernovaMenu(Supernova* supernova)
     QString name=supernova->name();
     float mag = supernova->mag();
     QString type = supernova->getType();
-    initPopupMenu( supernova, name, i18n( "supernova" ), i18n("%1<sup>m</sup>, %2", mag, type) );
+    initPopupMenu( supernova, name, xi18n( "supernova" ), xi18n("%1<sup>m</sup>, %2", mag, type) );
 }
 
 void KSPopupMenu::initPopupMenu( SkyObject *obj, QString name, QString type, QString info,
                                  bool showDetails, bool showObsList, bool showFlags )
 {
-    KStars* ks = KStars::Instance();
+    KStarsData* data = KStarsData::Instance();
+    SkyMap * map = SkyMap::Instance();
 
     clear();
-    bool showLabel = name != i18n("star") && !name.isEmpty();
+    bool showLabel = name != xi18n("star") && !name.isEmpty();
     if( name.isEmpty() )
-        name = i18n( "Empty sky" );
+        name = xi18n( "Empty sky" );
 
     addFancyLabel( name );
     addFancyLabel( type );
@@ -284,59 +288,60 @@ void KSPopupMenu::initPopupMenu( SkyObject *obj, QString name, QString type, QSt
     delete o;
 
     // Show 'Select this object' item when in object pointing mode and when obj is not empty sky
-    if(KStars::Instance()->map()->isInObjectPointingMode() && obj->type() != 21) {
-        addAction( i18n( "Select this object"), KStars::Instance()->map(), SLOT(slotObjectSelected()));
+    if(map->isInObjectPointingMode() && obj->type() != 21)
+    {
+        addAction( xi18n( "Select this object"), map, SLOT(slotObjectSelected()));
     }
 
     //Insert item for centering on object
-    addAction( i18n( "Center && Track" ), ks->map(), SLOT( slotCenter() ) );
+    addAction( xi18n( "Center && Track" ), map, SLOT( slotCenter() ) );
 
-    if ( showFlags ) {
+    if ( showFlags )
+    {
         //Insert actions for flag operations
         initFlagActions( obj );
     }
 
     //Insert item for measuring distances
     //FIXME: add key shortcut to menu items properly!
-    addAction( i18n( "Angular Distance To...            [" ), ks->map(),
-               SLOT(slotBeginAngularDistance()) );
-    addAction( i18n( "Starhop from here to...            " ), ks->map(),
-               SLOT(slotBeginStarHop()) ); 
+    addAction( xi18n( "Angular Distance To...            [" ), map, SLOT(slotBeginAngularDistance()) );
+    addAction( xi18n( "Starhop from here to...            " ), map, SLOT(slotBeginStarHop()) );
 
     //Insert item for Showing details dialog
     if ( showDetails )
-        addAction( i18nc( "Show Detailed Information Dialog", "Details" ), ks->map(), SLOT( slotDetail() ) );
+        addAction( xi18nc( "Show Detailed Information Dialog", "Details" ), map, SLOT( slotDetail() ) );
     //Insert "Add/Remove Label" item
-    if ( showLabel ) {
-        if ( ks->map()->isObjectLabeled( obj ) ) {
-            addAction( i18n( "Remove Label" ), ks->map(), SLOT( slotRemoveObjectLabel() ) );
+    if ( showLabel )
+    {
+        if ( map->isObjectLabeled( obj ) ) {
+            addAction( xi18n( "Remove Label" ), map, SLOT( slotRemoveObjectLabel() ) );
         } else {
-            addAction( i18n( "Attach Label" ), ks->map(), SLOT( slotAddObjectLabel() ) );
+            addAction( xi18n( "Attach Label" ), map, SLOT( slotAddObjectLabel() ) );
         }
     }
     // Should show observing list
     if( showObsList ) {
-        if ( ks->observingList()->contains( obj ) )
-            addAction( i18n("Remove From Observing WishList"), ks->observingList(), SLOT( slotRemoveObject() ) );
+        if ( data->observingList()->contains( obj ) )
+            addAction( xi18n("Remove From Observing WishList"), data->observingList(), SLOT( slotRemoveObject() ) );
         else
-            addAction( i18n("Add to Observing WishList"), ks->observingList(), SLOT( slotAddObject() ) );
+            addAction( xi18n("Add to Observing WishList"), data->observingList(), SLOT( slotAddObject() ) );
     }
     // Should we show trail actions
     TrailObject* t = dynamic_cast<TrailObject*>( obj );
     if( t ) {
         if( t->hasTrail() )
-            addAction( i18n( "Remove Trail" ), ks->map(), SLOT( slotRemovePlanetTrail() ) );
+            addAction( xi18n( "Remove Trail" ), map, SLOT( slotRemovePlanetTrail() ) );
         else
-            addAction( i18n( "Add Trail" ), ks->map(), SLOT( slotAddPlanetTrail() ) );
+            addAction( xi18n( "Add Trail" ), map, SLOT( slotAddPlanetTrail() ) );
     }
 
     addSeparator();
 #ifdef HAVE_XPLANET
     if ( obj->isSolarSystem() && obj->type() != SkyObject::COMET ) { // FIXME: We now have asteroids -- so should this not be isMajorPlanet() || Pluto?
         QMenu *xplanetSubmenu = new QMenu();
-        xplanetSubmenu->setTitle( i18n( "Print Xplanet view" ) );
-        xplanetSubmenu->addAction( i18n( "To screen" ), ks->map(), SLOT( slotXplanetToScreen() ) );
-        xplanetSubmenu->addAction( i18n( "To file..." ), ks->map(), SLOT( slotXplanetToFile() ) );
+        xplanetSubmenu->setTitle( xi18n( "Print Xplanet view" ) );
+        xplanetSubmenu->addAction( xi18n( "To screen" ), map, SLOT( slotXplanetToScreen() ) );
+        xplanetSubmenu->addAction( xi18n( "To file..." ), map, SLOT( slotXplanetToFile() ) );
         addMenu( xplanetSubmenu );
     }
 #endif
@@ -351,21 +356,21 @@ void KSPopupMenu::initFlagActions( SkyObject *obj ) {
 
     if ( flags.size() == 0 ) {
         // There is no flag around clicked SkyObject
-        addAction( i18n( "Add flag..."), ks->map(), SLOT( slotAddFlag() ) );
+        addAction( xi18n( "Add flag..."), ks->map(), SLOT( slotAddFlag() ) );
     }
 
     else if( flags.size() == 1) {
         // There is only one flag around clicked SkyObject
-        addAction ( i18n ("Edit flag"), this, SLOT( slotEditFlag() ) );
-        addAction ( i18n ("Delete flag"), this, SLOT( slotDeleteFlag() ) );
+        addAction ( xi18n ("Edit flag"), this, SLOT( slotEditFlag() ) );
+        addAction ( xi18n ("Delete flag"), this, SLOT( slotDeleteFlag() ) );
 
         m_CurrentFlagIdx = flags.first();
     }
 
     else {
         // There are more than one flags around clicked SkyObject - we need to create submenus
-        QMenu *editMenu = new QMenu ( i18n ( "Edit flag..."), KStars::Instance() );
-        QMenu *deleteMenu = new QMenu ( i18n ( "Delete flag..."), KStars::Instance() );
+        QMenu *editMenu = new QMenu ( xi18n ( "Edit flag..."), KStars::Instance() );
+        QMenu *deleteMenu = new QMenu ( xi18n ( "Delete flag..."), KStars::Instance() );
 
         connect( editMenu, SIGNAL( triggered(QAction*) ), this, SLOT( slotEditFlag(QAction*) ) );
         connect( deleteMenu, SIGNAL( triggered(QAction*) ), this, SLOT( slotDeleteFlag(QAction*) ) );
@@ -416,7 +421,7 @@ void KSPopupMenu::addLinksToMenu( SkyObject *obj, bool showDSS ) {
     itListEnd = obj->ImageList().constEnd();
     if( ! obj->ImageList().isEmpty() ) {
         QMenu *imageLinkSubMenu= new QMenu();
-        imageLinkSubMenu->setTitle( i18n( "Image Resources" ) );
+        imageLinkSubMenu->setTitle( xi18n( "Image Resources" ) );
         for ( ; itList != itListEnd; ++itList ) {
             QString t = QString(*itTitle);
             sURL = QString(*itList);
@@ -427,8 +432,8 @@ void KSPopupMenu::addLinksToMenu( SkyObject *obj, bool showDSS ) {
     }
 
     if ( showDSS ) {
-        addAction( i18nc( "Sloan Digital Sky Survey", "Show SDSS Image" ), ks->map(), SLOT( slotSDSS() ) );
-        addAction( i18nc( "Digitized Sky Survey", "Show DSS Image" ), ks->map(), SLOT( slotDSS() ) );
+        addAction( xi18nc( "Sloan Digital Sky Survey", "Show SDSS Image" ), ks->map(), SLOT( slotSDSS() ) );
+        addAction( xi18nc( "Digitized Sky Survey", "Show DSS Image" ), ks->map(), SLOT( slotDSS() ) );
     }
 
     if( showDSS )
@@ -440,7 +445,7 @@ void KSPopupMenu::addLinksToMenu( SkyObject *obj, bool showDSS ) {
 
     if( ! obj->InfoList().isEmpty() ) {
         QMenu *infoLinkSubMenu= new QMenu();
-        infoLinkSubMenu->setTitle( i18n( "Information Resources" ) );
+        infoLinkSubMenu->setTitle( xi18n( "Information Resources" ) );
         for ( ; itList != itListEnd; ++itList ) {
             QString t = QString(*itTitle);
             sURL = QString(*itList);
@@ -453,7 +458,7 @@ void KSPopupMenu::addLinksToMenu( SkyObject *obj, bool showDSS ) {
 
 void KSPopupMenu::addINDI()
 {
-#ifdef HAVE_INDI_H
+#ifdef HAVE_INDI
 
     if (INDIListener::Instance()->size() == 0)
         return;
@@ -468,7 +473,7 @@ void KSPopupMenu::addINDI()
         //if (bd->isConnected() == false)
         //    continue;
 
-        KMenu* menuDevice = NULL;
+        QMenu* menuDevice = NULL;
         ISD::GDInterface *telescope = NULL;
 
        foreach(INDI::Property *pp, gd->getProperties())
@@ -484,7 +489,7 @@ void KSPopupMenu::addINDI()
                 {
                     if (menuDevice == NULL)
                     {
-                        menuDevice = new KMenu(gd->getDeviceName());
+                        menuDevice = new QMenu(gd->getDeviceName());
                         addMenu(menuDevice);
                     }
 
@@ -526,7 +531,7 @@ void KSPopupMenu::addINDI()
         {
             menuDevice->addSeparator();
 
-            QAction *a = menuDevice->addAction(i18n("Center Crosshair"));
+            QAction *a = menuDevice->addAction(xi18n("Center Crosshair"));
 
             QSignalMapper *scopeMapper = new QSignalMapper(this);
             scopeMapper->setMapping(a, INDI_ENGAGE_TRACKING);
@@ -549,8 +554,7 @@ void KSPopupMenu::addFancyLabel(QString name, int deltaFontSize) {
         font.setPointSize( font.pointSize() + deltaFontSize );
         label->setFont( font );
     }
-    KAction* act = new KAction( this );
-    act->setDefaultWidget( label );
+    QWidgetAction * act = new QWidgetAction( this );
+    act->setDefaultWidget(label);
     addAction( act );
 }
-#include "kspopupmenu.moc"
