@@ -184,7 +184,7 @@ bool KStarsData::initialize() {
     return true;
 }
 
-void KStarsData::updateTime( GeoLocation *geo, SkyMap *skymap, const bool automaticDSTchange ) {
+void KStarsData::updateTime( GeoLocation *geo, const bool automaticDSTchange ) {
     // sync LTime with the simulation clock
     LTime = geo->UTtoLT( ut() );
     syncLST();
@@ -228,15 +228,9 @@ void KStarsData::updateTime( GeoLocation *geo, SkyMap *skymap, const bool automa
     if ( fabs( ut().djd() - LastSkyUpdate.djd() ) > 0.1/Options::zoomFactor() || clock()->isManualMode() ) {
         LastSkyUpdate = ut();
         m_preUpdateID++;
-        skyComposite()->update(); //omit KSNumbers arg == just update Alt/Az coords
+        skyComposite()->update(); //omit KSNumbers arg == just update Alt/Az coords // <-- Eh? -- asimha. Looks like this behavior / ideology has changed drastically.
 
-        //Update focus
-        skymap->updateFocus();
-
-        if ( clock()->isManualMode() )
-            QTimer::singleShot( 0, skymap, SLOT( forceUpdateNow() ) );
-        else
-            skymap->forceUpdate();
+        emit skyUpdate( clock()->isManualMode() );
     }
 }
 
@@ -342,7 +336,7 @@ void KStarsData::setLocation( const GeoLocation &l ) {
 
 SkyObject* KStarsData::objectNamed( const QString &name ) {
     if ( (name== "star") || (name== "nothing") || name.isEmpty() )
-        return NULL;
+        return 0;
     return skyComposite()->findByName( name );
 }
 
@@ -1027,6 +1021,7 @@ void KStarsData::syncFOV()
     Options::setFOVNames( all.intersect(names).toList() );
 }
 
+// FIXME: Why does KStarsData store the Execute instance??? -- asimha
 Execute* KStarsData::executeSession() {
     if( !m_Execute )
         m_Execute = new Execute();
@@ -1034,6 +1029,7 @@ Execute* KStarsData::executeSession() {
     return m_Execute;
 }
 
+// FIXME: Why does KStarsData store the ImageExporer instance??? KStarsData is supposed to work with no reference to KStars -- asimha
 ImageExporter * KStarsData::imageExporter()
 {
     if (!m_ImageExporter)
