@@ -17,9 +17,10 @@
 
 #include "loggingform.h"
 
-#include "QTextDocument"
-#include "QTextTable"
-#include "QPrinter"
+#include <QTextDocument>
+#include <QTextTable>
+#include <QtPrintSupport/QPrinter>
+
 #include "kstars.h"
 
 LoggingForm::LoggingForm()
@@ -49,24 +50,24 @@ void LoggingForm::createFinderChartLogger()
 
     QTextTable *table = cursor.insertTable(5, 4, tableFormat);
     table->mergeCells(0, 0, 1, 4);
-    table->cellAt(0, 0).firstCursorPosition().insertText(i18n("Observer:"), fieldCharFmt);
+    table->cellAt(0, 0).firstCursorPosition().insertText(xi18n("Observer:"), fieldCharFmt);
 
     table->mergeCells(1, 0, 1, 2);
-    table->cellAt(1, 0).firstCursorPosition().insertText(i18n("Date:"), fieldCharFmt);
+    table->cellAt(1, 0).firstCursorPosition().insertText(xi18n("Date:"), fieldCharFmt);
     table->mergeCells(1, 2, 1, 2);
-    table->cellAt(1, 2).firstCursorPosition().insertText(i18n("Time:"), fieldCharFmt);
+    table->cellAt(1, 2).firstCursorPosition().insertText(xi18n("Time:"), fieldCharFmt);
 
     table->mergeCells(2, 0, 1, 2);
-    table->cellAt(2, 0).firstCursorPosition().insertText(i18n("Site:"), fieldCharFmt);
-    table->cellAt(2, 2).firstCursorPosition().insertText(i18n("Seeing:"), fieldCharFmt);
-    table->cellAt(2, 3).firstCursorPosition().insertText(i18n("Trans:"), fieldCharFmt);
+    table->cellAt(2, 0).firstCursorPosition().insertText(xi18n("Site:"), fieldCharFmt);
+    table->cellAt(2, 2).firstCursorPosition().insertText(xi18n("Seeing:"), fieldCharFmt);
+    table->cellAt(2, 3).firstCursorPosition().insertText(xi18n("Trans:"), fieldCharFmt);
 
     table->mergeCells(3, 0, 1, 4);
-    table->cellAt(3, 0).firstCursorPosition().insertText(i18n("Telescope:"), fieldCharFmt);
+    table->cellAt(3, 0).firstCursorPosition().insertText(xi18n("Telescope:"), fieldCharFmt);
 
     table->mergeCells(4, 0, 1, 3);
-    table->cellAt(4, 0).firstCursorPosition().insertText(i18n("Eyepiece:"), fieldCharFmt);
-    table->cellAt(4, 3).firstCursorPosition().insertText(i18n("Power:"), fieldCharFmt);
+    table->cellAt(4, 0).firstCursorPosition().insertText(xi18n("Eyepiece:"), fieldCharFmt);
+    table->cellAt(4, 3).firstCursorPosition().insertText(xi18n("Power:"), fieldCharFmt);
 }
 
 QTextDocument* LoggingForm::getDocument()
