@@ -17,6 +17,10 @@
 
 #include "printingwizard.h"
 
+#include <QStackedWidget>
+#include <QtPrintSupport/QPrinter>
+#include <QStandardPaths>
+
 #include "finderchart.h"
 #include "loggingform.h"
 #include "detailstable.h"
@@ -34,9 +38,6 @@
 #include "kstars/kstarsdata.h"
 #include "skymap.h"
 #include "legend.h"
-#include "QStackedWidget"
-#include "QPrinter"
-#include "kstandarddirs.h"
 #include "shfovexporter.h"
 #include "Options.h"
 
@@ -45,7 +46,7 @@ PWizWelcomeUI::PWizWelcomeUI(QWidget *parent) : QFrame(parent)
     setupUi(this);
 }
 
-PrintingWizard::PrintingWizard(QWidget *parent) : KDialog(parent),
+PrintingWizard::PrintingWizard(QWidget *parent) : QDialog(parent),
     m_KStars(KStars::Instance()), m_FinderChart(0), m_SkyObject(0),
     m_FovType(FT_UNDEFINED), m_FovImageSize(QSize(500, 500)), m_ShBeginObject(0),
     m_PointingShBegin(false), m_SwitchColors(false), m_RecapturingFov(false),
@@ -54,7 +55,6 @@ PrintingWizard::PrintingWizard(QWidget *parent) : KDialog(parent),
     m_Printer = new QPrinter(QPrinter::ScreenResolution);
 
     setupWidgets();
-    setupConnections();
 }
 
 PrintingWizard::~PrintingWizard()
@@ -75,7 +75,7 @@ void PrintingWizard::updateStepButtons()
     {
     case PW_OBJECT_SELECTION: // object selection
         {
-            enableButton(KDialog::User1, m_SkyObject);
+            nextB->setEnabled(m_SkyObject != NULL);
             break;
         }
     }
@@ -218,8 +218,8 @@ void PrintingWizard::beginShFovCapture()
     // Calculate path and check if it's not empty
     if(!exporter.calculatePath(*m_SkyObject, *m_ShBeginObject, fovArcmin / 60, m_WizFovShUI->getMaglim()))
     {
-        KMessageBox::information(this, i18n("Star hopper returned empty path. We advise you to change star hopping settings or use manual capture mode."),
-                                 i18n("Star hopper failed to find path"));
+        KMessageBox::information(this, xi18n("Star hopper returned empty path. We advise you to change star hopping settings or use manual capture mode."),
+                                 xi18n("Star hopper failed to find path"));
         return;
     }
 
@@ -396,14 +396,29 @@ void PrintingWizard::slotNextPage()
 void PrintingWizard::setupWidgets()
 {
     m_WizardStack = new QStackedWidget(this);
-    setMainWidget(m_WizardStack);
 
-    setCaption(i18n("Printing Wizard"));
+    setWindowTitle(xi18n("Printing Wizard"));
 
-    setButtons(KDialog::User1 | KDialog::User2 | KDialog::Close);
+    QVBoxLayout *mainLayout= new QVBoxLayout;
+    mainLayout->addWidget(m_WizardStack);
+    setLayout(mainLayout);
 
-    setButtonGuiItem(KDialog::User1, KGuiItem(i18n("&Next >"), QString(), i18n("Go to next Wizard page")));
-    setButtonGuiItem(KDialog::User2, KGuiItem(i18n("< &Back"), QString(), i18n("Go to previous Wizard page")));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    mainLayout->addWidget(buttonBox);
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+
+    nextB = new QPushButton(xi18n("&Next >"));
+    nextB->setToolTip(xi18n("Go to next Wizard page"));
+    nextB->setDefault(true);
+    backB = new QPushButton(xi18n("< &Back"));
+    backB->setToolTip(xi18n("Go to previous Wizard page"));
+    backB->setEnabled(false);
+
+    buttonBox->addButton(backB, QDialogButtonBox::ActionRole);
+    buttonBox->addButton(nextB, QDialogButtonBox::ActionRole);
+
+    connect(nextB, SIGNAL(clicked()), this, SLOT(slotNextPage()));
+    connect(backB, SIGNAL(clicked()), this, SLOT(slotPrevPage()));
 
     // Create step widgets
     m_WizWelcomeUI = new PWizWelcomeUI(m_WizardStack);
@@ -431,7 +446,7 @@ void PrintingWizard::setupWidgets()
 
     // Set banner images for steps
     QPixmap bannerImg;
-    if(bannerImg.load(KStandardDirs::locate("appdata", "wzstars.png")))
+    if(bannerImg.load(QStandardPaths::locate(QStandardPaths::DataLocation, "wzstars.png")))
     {
         m_WizWelcomeUI->banner->setPixmap(bannerImg);
         m_WizObjectSelectionUI->banner->setPixmap(bannerImg);
@@ -445,19 +460,14 @@ void PrintingWizard::setupWidgets()
         m_WizPrintUI->banner->setPixmap(bannerImg);
     }
 
-    enableButton(KDialog::User2, false);
-}
 
-void PrintingWizard::setupConnections()
-{
-    connect(this, SIGNAL(user1Clicked()), this, SLOT(slotNextPage()));
-    connect(this, SIGNAL(user2Clicked()), this, SLOT(slotPrevPage()));
+    backB->setEnabled(false);
 }
 
 void PrintingWizard::updateButtons()
 {
-    enableButton(KDialog::User1, m_WizardStack->currentIndex() < m_WizardStack->count() - 1);
-    enableButton(KDialog::User2, m_WizardStack->currentIndex() > 0);
+    nextB->setEnabled( m_WizardStack->currentIndex() < m_WizardStack->count() - 1);
+    backB->setEnabled(m_WizardStack->currentIndex() > 0);
 }
 
 void PrintingWizard::slewAndBeginCapture(SkyPoint *center, FOV *fov)
@@ -520,17 +530,17 @@ void PrintingWizard::createFinderChart()
     {
         LoggingForm chartLogger;
         chartLogger.createFinderChartLogger();
-        m_FinderChart->insertSectionTitle(i18n("Logging Form"));
+        m_FinderChart->insertSectionTitle(xi18n("Logging Form"));
         m_FinderChart->insertLoggingForm(&chartLogger);
     }
 
-    m_FinderChart->insertSectionTitle(i18n("Field of View Snapshots"));
+    m_FinderChart->insertSectionTitle(xi18n("Field of View Snapshots"));
 
     // Insert FOV images and descriptions
     for(int i = 0; i < m_FovSnapshots.size(); i++)
     {
         FOV *fov = m_FovSnapshots.at(i)->getFov();
-        QString fovDescription = i18nc("%1 = FOV index, %2 = FOV count, %3 = FOV name, %4 = FOV X size, %5 = FOV Y size",
+        QString fovDescription = xi18nc("%1 = FOV index, %2 = FOV count, %3 = FOV name, %4 = FOV X size, %5 = FOV Y size",
                                  "FOV (%1/%2): %3 (%4' x %5')",
                                  QString::number(i + 1),
                                  QString::number(m_FovSnapshots.size()),
@@ -545,7 +555,7 @@ void PrintingWizard::createFinderChart()
        m_WizChartContentsUI->isRSTTableChecked() ||
        m_WizChartContentsUI->isAstComTableChecked())
     {
-        m_FinderChart->insertSectionTitle(i18n("Details About Object"));
+        m_FinderChart->insertSectionTitle(xi18n("Details About Object"));
         m_FinderChart->insertGeoTimeInfo(KStarsData::Instance()->ut(), KStarsData::Instance()->geo());
     }
 
