@@ -155,16 +155,17 @@ void AsteroidsComponent::loadData() {
 
         JD = static_cast<double>(mJD) + 2400000.5;
 
+        KSAsteroid *new_asteroid = NULL;
         // JM: Hack since asteroid file (Generated by JPL) is missing important Pluto data
         // I emailed JPL and this hack will be removed once they update the data!
         if (name == "Pluto")
-            diameter = 2368;
+        {
+           diameter = 2368;
+           new_asteroid = new KSAsteroid( catN, name, "pluto", JD, a, e, dms(dble_i), dms(dble_w), dms(dble_N), dms(dble_M), H, G );
+         }
+         else
+           new_asteroid = new KSAsteroid( catN, name, QString(), JD, a, e, dms(dble_i), dms(dble_w), dms(dble_N), dms(dble_M), H, G );
 
-        KSAsteroid *new_asteroid = new KSAsteroid( catN, name, QString(), JD,
-                                          a, e,
-                                          dms(dble_i), dms(dble_w),
-                                          dms(dble_N), dms(dble_M),
-                                          H, G );
         new_asteroid->setPerihelion(q);
         new_asteroid->setOrbitID(orbit_id);
         new_asteroid->setNEO(neo);
@@ -210,7 +211,12 @@ void AsteroidsComponent::draw( SkyPainter *skyp )
         if ( ast->mag() > Options::magLimitAsteroid() || std::isnan(ast->mag()) != 0)
             continue;
 
-        bool drawn = skyp->drawPointSource(ast,ast->mag());
+        bool drawn = false;
+
+        if (ast->image().isNull() == false)
+            drawn = skyp->drawPlanet(ast);
+        else
+            drawn = skyp->drawPointSource(ast,ast->mag());
 
         if ( drawn && !( hideLabels || ast->mag() >= labelMagLimit ) )
             SkyLabeler::AddLabel( ast, SkyLabeler::ASTEROID_LABEL );
