@@ -21,7 +21,7 @@
 #include <QPointF>
 #include <QPolygonF>
 
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "kstarsdata.h"
 #include "skymap.h"
@@ -37,14 +37,14 @@
 
 
 MilkyWay::MilkyWay( SkyComposite *parent ) :
-    LineListIndex( parent, i18n("Milky Way") )
+    LineListIndex( parent, xi18n("Milky Way") )
 {
     intro();
     // Milky way
-    loadContours("milkyway.dat", i18n("Loading Milky Way"));
+    loadContours("milkyway.dat", xi18n("Loading Milky Way"));
     // Magellanic clouds
-    loadContours("lmc.dat", i18n("Loading Large Magellanic Clouds"));
-    loadContours("smc.dat", i18n("Loading Small Magellanic Clouds"));
+    loadContours("lmc.dat", xi18n("Loading Large Magellanic Clouds"));
+    loadContours("smc.dat", xi18n("Loading Small Magellanic Clouds"));
     summary();
 }
 
@@ -103,7 +103,7 @@ void MilkyWay::loadContours(QString fname, QString greeting) {
         double ra  = line.mid( 2,  8 ).toDouble(&okRA);
         double dec = line.mid( 11, 8 ).toDouble(&okDec);
         if( !okRA || !okDec) {
-            kDebug() << QString("%1: conversion error on line: %2\n").arg(fname).arg(fileReader.lineNumber());
+            qDebug() << QString("%1: conversion error on line: %2\n").arg(fname).arg(fileReader.lineNumber());
             continue;
         }
 
