@@ -21,13 +21,8 @@
 #include <QObject>
 #include <QProgressDialog>
 
-#include <kjob.h>
-#include <kio/job.h>
-#include <kio/copyjob.h>
-#include <kio/netaccess.h>
-#include <kio/jobuidelegate.h>
-
-#include "klocale.h"
+#include <KJobUiDelegate>
+#include <KLocalizedString>
 
 #include "satellitegroup.h"
 #include "Options.h"
@@ -44,7 +39,7 @@ SatellitesComponent::SatellitesComponent( SkyComposite *parent ) :
     
     if ( ! fileReader.open( "satellites.dat" ) ) return;
 
-    emitProgressText( i18n("Loading satellites" ) );
+    emitProgressText( xi18n("Loading satellites" ) );
     
 
     while ( fileReader.hasMoreLines() ) {
@@ -52,7 +47,22 @@ SatellitesComponent::SatellitesComponent( SkyComposite *parent ) :
         if ( line.trimmed().isEmpty() || line.at( 0 ) == '#' )
             continue;
         group_infos = line.split( ';' );
-        m_groups.append( new SatelliteGroup( group_infos.at( 0 ), group_infos.at( 1 ), KUrl( group_infos.at( 2 ) ) ) );
+        m_groups.append( new SatelliteGroup( group_infos.at( 0 ), group_infos.at( 1 ), QUrl( group_infos.at( 2 ) ) ) );
+    }
+
+    objectNames(SkyObject::SATELLITE).clear();
+
+    foreach( SatelliteGroup *group, m_groups )
+    {
+        for ( int i=0; i<group->size(); i++ )
+        {
+            Satellite *sat = group->at( i );
+            if ( sat->selected() && nameHash.contains(sat->name().toLower()) == false)
+            {
+                objectNames(SkyObject::SATELLITE).append(sat->name());
+                nameHash[sat->name().toLower()] = sat;
+            }
+        }
     }
 }
 
@@ -112,7 +122,7 @@ void SatellitesComponent::updateTLEs()
 {
     int i = 0;
     
-    QProgressDialog progressDlg( i18n( "Update TLEs..." ), i18n( "Abort" ), 0, m_groups.count() );
+    QProgressDialog progressDlg( xi18n( "Update TLEs..." ), xi18n( "Abort" ), 0, m_groups.count() );
     progressDlg.setWindowModality( Qt::WindowModal );
     progressDlg.setValue( 0 );
         
@@ -123,14 +133,16 @@ void SatellitesComponent::updateTLEs()
         if( group->tleUrl().isEmpty() )
             continue;
         
-        progressDlg.setLabelText( i18n( "Update %1 satellites", group->name() ) );
-        KIO::Job* getJob = KIO::file_copy( group->tleUrl(), group->tleFilename(), -1, KIO::Overwrite | KIO::HideProgressInfo );
-        if( KIO::NetAccess::synchronousRun( getJob, 0 ) ) {
+        progressDlg.setLabelText( xi18n( "Update %1 satellites", group->name() ) );
+        KIO::Job* getJob = KIO::file_copy(group->tleUrl(), group->tleFilename(), -1, KIO::Overwrite | KIO::HideProgressInfo );
+        if( getJob->exec() )
+        {
             group->readTLE();
             group->updateSatellitesPos();
             progressDlg.setValue( ++i );
-        } else {
-            getJob->ui()->showErrorMessage();
+        } else
+        {
+            getJob->uiDelegate()->showErrorMessage();
         }   
     }
 }
@@ -170,9 +182,9 @@ SkyObject* SatellitesComponent::objectNearest( SkyPoint* p, double& maxrad ) {
                 continue;
 
             r = sat->angularDistanceTo( p ).Degrees();
-            //kDebug() << sat->name();
-            //kDebug() << "r = " << r << " - max = " << rBest;
-            //kDebug() << "ra2=" << sat->ra().Degrees() << " - dec2=" << sat->dec().Degrees();
+            //qDebug() << sat->name();
+            //qDebug() << "r = " << r << " - max = " << rBest;
+            //qDebug() << "ra2=" << sat->ra().Degrees() << " - dec2=" << sat->dec().Degrees();
             if ( r < rBest ) {
                 rBest = r;
                 oBest = sat;
@@ -183,3 +195,8 @@ SkyObject* SatellitesComponent::objectNearest( SkyPoint* p, double& maxrad ) {
     maxrad = rBest;
     return oBest;
 }
+
+SkyObject* SatellitesComponent::findByName( const QString &name )
+{
+     return nameHash[ name.toLower() ];
+}
