@@ -17,13 +17,14 @@
 
 #include "ksplanet.h"
 
+#include <typeinfo>
+
 #include <cmath>
 
 #include <QFile>
 #include <QTextStream>
 
-#include <kdebug.h>
-#include <kglobal.h>
+#include <QDebug>
 
 #include "ksnumbers.h"
 #include "ksutils.h"
@@ -122,52 +123,53 @@ KSPlanet::KSPlanet( int n )
 {
     switch ( n ) {
         case MERCURY:
-            KSPlanetBase::init( i18n("Mercury"), "mercury", KSPlanetBase::planetColor[KSPlanetBase::MERCURY], 4879.4 );
+            KSPlanetBase::init( xi18n("Mercury"), "mercury", KSPlanetBase::planetColor[KSPlanetBase::MERCURY], 4879.4 );
             break;
         case VENUS:
-            KSPlanetBase::init( i18n("Venus"), "venus", KSPlanetBase::planetColor[KSPlanetBase::VENUS], 12103.6 );
+            KSPlanetBase::init( xi18n("Venus"), "venus", KSPlanetBase::planetColor[KSPlanetBase::VENUS], 12103.6 );
             break;
         case MARS:
-            KSPlanetBase::init( i18n("Mars"), "mars", KSPlanetBase::planetColor[KSPlanetBase::MARS], 6792.4 );
+            KSPlanetBase::init( xi18n("Mars"), "mars", KSPlanetBase::planetColor[KSPlanetBase::MARS], 6792.4 );
             break;
         case JUPITER:
-            KSPlanetBase::init( i18n("Jupiter"), "jupiter", KSPlanetBase::planetColor[KSPlanetBase::JUPITER], 142984. );
+            KSPlanetBase::init( xi18n("Jupiter"), "jupiter", KSPlanetBase::planetColor[KSPlanetBase::JUPITER], 142984. );
             break;
         case SATURN:
-            KSPlanetBase::init( i18n("Saturn"), "saturn", KSPlanetBase::planetColor[KSPlanetBase::SATURN], 120536. );
+            KSPlanetBase::init( xi18n("Saturn"), "saturn", KSPlanetBase::planetColor[KSPlanetBase::SATURN], 120536. );
             break;
         case URANUS:
-            KSPlanetBase::init( i18n("Uranus"), "uranus", KSPlanetBase::planetColor[KSPlanetBase::URANUS], 51118. );
+            KSPlanetBase::init( xi18n("Uranus"), "uranus", KSPlanetBase::planetColor[KSPlanetBase::URANUS], 51118. );
             break;
         case NEPTUNE:
-            KSPlanetBase::init( i18n("Neptune"), "neptune", KSPlanetBase::planetColor[KSPlanetBase::NEPTUNE], 49572. );
+            KSPlanetBase::init( xi18n("Neptune"), "neptune", KSPlanetBase::planetColor[KSPlanetBase::NEPTUNE], 49572. );
             break;
         default:
-            kDebug() << i18n("Error: Illegal identifier in KSPlanet constructor: %1", n) << endl;
+            qDebug() << xi18n("Error: Illegal identifier in KSPlanet constructor: %1", n) << endl;
             break;
     }
 }
 
 KSPlanet* KSPlanet::clone() const
 {
+    Q_ASSERT( typeid( this ) == typeid( static_cast<const KSPlanet *>( this ) ) ); // Ensure we are not slicing a derived class
     return new KSPlanet(*this);
 }
-        
+
 // TODO: Get rid of this dirty hack post KDE 4.2 release
 QString KSPlanet::untranslatedName() const {
-    if( name() == i18n( "Mercury" ) )
+    if( name() == xi18n( "Mercury" ) )
         return "Mercury";
-    else if( name() == i18n( "Venus" ) )
+    else if( name() == xi18n( "Venus" ) )
         return "Venus";
-    else if( name() == i18n( "Mars" ) )
+    else if( name() == xi18n( "Mars" ) )
         return "Mars";
-    else if( name() == i18n( "Jupiter" ) )
+    else if( name() == xi18n( "Jupiter" ) )
         return "Jupiter";
-    else if( name() == i18n( "Saturn" ) )
+    else if( name() == xi18n( "Saturn" ) )
         return "Saturn";
-    else if( name() == i18n( "Uranus" ) )
+    else if( name() == xi18n( "Uranus" ) )
         return "Uranus";
-    else if( name() == i18n( "Neptune" ) )
+    else if( name() == xi18n( "Neptune" ) )
         return "Neptune";
     else
         return name();
@@ -193,7 +195,7 @@ void KSPlanet::calcEcliptic(double Tau, EclipticPosition &epret) const {
         epret.longitude = dms(0.0);
         epret.latitude  = dms(0.0);
         epret.radius    = 0.0;
-        kError() << "Could not get data for '" << name() << "'" << endl;
+        qWarning() << "Could not get data for '" << name() << "'" << endl;
         return;
     }
 
@@ -203,13 +205,13 @@ void KSPlanet::calcEcliptic(double Tau, EclipticPosition &epret) const {
         for (int j = 0; j < odc.Lon[i].size(); ++j) {
             sum[i] += odc.Lon[i][j].A * cos( odc.Lon[i][j].B + odc.Lon[i][j].C*Tau );
             /*
-            kDebug() << "sum[" << i <<"] =" << sum[i] <<
+            qDebug() << "sum[" << i <<"] =" << sum[i] <<
             	" A = " << odc.Lon[i][j].A << " B = " << odc.Lon[i][j].B <<
             	" C = " << odc.Lon[i][j].C << endl;
             	*/
         }
         sum[i] *= Tpow[i];
-        //kDebug() << name() << " : sum[" << i << "] = " << sum[i];
+        //qDebug() << name() << " : sum[" << i << "] = " << sum[i];
     }
 
     epret.longitude.setRadians( sum[0] + sum[1] + sum[2] + sum[3] + sum[4] + sum[5] );
@@ -239,7 +241,7 @@ void KSPlanet::calcEcliptic(double Tau, EclipticPosition &epret) const {
     epret.radius = sum[0] + sum[1] + sum[2] + sum[3] + sum[4] + sum[5];
 
     /*
-    kDebug() << name() << " pre: Lat = " << epret.latitude.toDMSString() << " Long = " <<
+    qDebug() << name() << " pre: Lat = " << epret.latitude.toDMSString() << " Long = " <<
     	epret.longitude.toDMSString() << " Dist = " << epret.radius << endl;
     */
 
@@ -337,16 +339,16 @@ void KSPlanet::findMagnitude(const KSNumbers* num)
     double phase = this->phase().Degrees();
     double f1 = phase/100.;
 
-    if( name() == i18n( "Mercury" ) ) {
+    if( name() == xi18n( "Mercury" ) ) {
         if ( phase > 150. ) f1 = 1.5;
         magnitude = -0.36 + param + 3.8*f1 - 2.73*f1*f1 + 2*f1*f1*f1;
-    } else if( name() == i18n( "Venus" ) ) {
+    } else if( name() == xi18n( "Venus" ) ) {
         magnitude = -4.29 + param + 0.09*f1 + 2.39*f1*f1 - 0.65*f1*f1*f1;
-    } else if( name() == i18n( "Mars" ) ) {
+    } else if( name() == xi18n( "Mars" ) ) {
         magnitude = -1.52 + param + 0.016*phase;
-    } else if( name() == i18n( "Jupiter" ) ) {
+    } else if( name() == xi18n( "Jupiter" ) ) {
         magnitude = -9.25 + param + 0.005*phase;
-    } else if( name() == i18n( "Saturn" ) ) {
+    } else if( name() == xi18n( "Saturn" ) ) {
         double T = num->julianCenturies();
         double a0 = (40.66-4.695*T)* dms::PI / 180.;
         double d0 = (83.52+0.403*T)* dms::PI / 180.;
@@ -354,9 +356,9 @@ void KSPlanet::findMagnitude(const KSNumbers* num)
         sinx = fabs(sinx-sin(d0)*sinDec);
         double rings = -2.6*sinx + 1.25*sinx*sinx;
         magnitude = -8.88 + param + 0.044*phase + rings;
-    } else if( name() == i18n( "Uranus" ) ) {
+    } else if( name() == xi18n( "Uranus" ) ) {
         magnitude = -7.19 + param + 0.0028*phase;
-    } else if( name() == i18n( "Neptune" ) ) {
+    } else if( name() == xi18n( "Neptune" ) ) {
         magnitude = -6.87 + param;
     }
     setMag(magnitude);
@@ -365,21 +367,21 @@ void KSPlanet::findMagnitude(const KSNumbers* num)
 SkyObject::UID KSPlanet::getUID() const
 {
     SkyObject::UID n;
-    if( name() == i18n( "Mercury" ) ) {
+    if( name() == xi18n( "Mercury" ) ) {
         n = 1;
-    } else if( name() == i18n( "Venus" ) ) {
+    } else if( name() == xi18n( "Venus" ) ) {
         n = 2;
-    } else if( name() == i18n( "Earth" ) ) {
+    } else if( name() == xi18n( "Earth" ) ) {
         n = 3;
-    } else if( name() == i18n( "Mars" ) ) {
+    } else if( name() == xi18n( "Mars" ) ) {
         n = 4;
-    } else if( name() == i18n( "Jupiter" ) ) {
+    } else if( name() == xi18n( "Jupiter" ) ) {
         n = 5;
-    } else if( name() == i18n( "Saturn" ) ) {
+    } else if( name() == xi18n( "Saturn" ) ) {
         n = 6;
-    } else if( name() == i18n( "Uranus" ) ) {
+    } else if( name() == xi18n( "Uranus" ) ) {
         n = 7;
-    } else if( name() == i18n( "Neptune" ) ) {
+    } else if( name() == xi18n( "Neptune" ) ) {
         n = 8;
     } else {
         return SkyObject::invalidUID;
