@@ -1,4 +1,3 @@
-
 /***************************************************************************
                           ksplanetbase.h  -  K Desktop Planetarium
                              -------------------
@@ -24,12 +23,11 @@
 #include <QImage>
 #include <QColor>
 
-#include <kdebug.h>
+#include <QDebug>
 
 #include "trailobject.h"
 
 class KSNumbers;
-class KSPopupMenu;
 
 /**
  *@class EclipticPosition
@@ -70,7 +68,7 @@ public:
       *@param c color of the symbol to use for this planet
       *@param pSize the planet's physical size, in km
       */
-    explicit KSPlanetBase( const QString &s = i18n("unnamed"),
+    explicit KSPlanetBase( const QString &s = xi18n("unnamed"),
                            const QString &image_file=QString(),
                            const QColor &c=Qt::white, double pSize=0 );
 
@@ -79,7 +77,8 @@ public:
 
     void init(const QString &s, const QString &image_file, const QColor &c, double pSize );
 
-    enum Planets { MERCURY=0, VENUS=1, MARS=2, JUPITER=3, SATURN=4, URANUS=5, NEPTUNE=6, PLUTO=7, SUN=8, MOON=9, UNKNOWN_PLANET };
+    //enum Planets { MERCURY=0, VENUS=1, MARS=2, JUPITER=3, SATURN=4, URANUS=5, NEPTUNE=6, PLUTO=7, SUN=8, MOON=9, UNKNOWN_PLANET };
+    enum Planets { MERCURY=0, VENUS=1, MARS=2, JUPITER=3, SATURN=4, URANUS=5, NEPTUNE=6, SUN=7, MOON=8, UNKNOWN_PLANET };
 
     static KSPlanetBase* createPlanet( int n );
 
@@ -93,28 +92,28 @@ public:
     /** @return pointer to Ecliptic Latitude coordinate */
     const dms& ecLat() const { return ep.latitude; }
 
-    /**@short Set Ecliptic Geocentric Longitude according to argument.
+    /** @short Set Ecliptic Geocentric Longitude according to argument.
      * @param elong Ecliptic Longitude
      */
     void setEcLong( dms elong ) { ep.longitude = elong; }
 
-    /**@short Set Ecliptic Geocentric Latitude according to argument.
+    /** @short Set Ecliptic Geocentric Latitude according to argument.
      * @param elat Ecliptic Latitude
      */
     void setEcLat( dms elat ) { ep.latitude = elat; }
 
-    /**@return pointer to Ecliptic Heliocentric Longitude coordinate */
+    /** @return pointer to Ecliptic Heliocentric Longitude coordinate */
     const dms& helEcLong() const { return helEcPos.longitude; }
 
-    /**@return pointer to Ecliptic Heliocentric Latitude coordinate */
+    /** @return pointer to Ecliptic Heliocentric Latitude coordinate */
     const dms& helEcLat() const { return helEcPos.latitude; }
 
-    /**@short Convert Ecliptic logitude/latitude to Right Ascension/Declination.
+    /** @short Convert Ecliptic logitude/latitude to Right Ascension/Declination.
      * @param Obliquity current Obliquity of the Ecliptic (angle from Equator)
      */
     void EclipticToEquatorial( const dms *Obliquity );
 
-    /**@short Convert Right Ascension/Declination to Ecliptic logitude/latitude.
+    /** @short Convert Right Ascension/Declination to Ecliptic logitude/latitude.
      * @param Obliquity current Obliquity of the Ecliptic (angle from Equator)
      */
     void EquatorialToEcliptic( const dms *Obliquity );
@@ -122,23 +121,23 @@ public:
     /** @return pointer to this planet's texture */
     const QImage& image() const { return m_image; }
 
-    /**@return distance from Sun, in Astronomical Units (1 AU is Earth-Sun distance) */
+    /** @return distance from Sun, in Astronomical Units (1 AU is Earth-Sun distance) */
     double rsun() const { return ep.radius; }
 
-    /**@short Set the solar distance in AU.
+    /** @short Set the solar distance in AU.
      * @param r the new solar distance in AU
      */
     void setRsun( double r ) { ep.radius = r; }
 
-    /**@return distance from Earth, in Astronomical Units (1 AU is Earth-Sun distance) */
+    /** @return distance from Earth, in Astronomical Units (1 AU is Earth-Sun distance) */
     double rearth() const { return Rearth; }
 
-    /**@short Set the distance from Earth, in AU.
+    /** @short Set the distance from Earth, in AU.
      * @param r the new earth-distance in AU
      */
     void setRearth( double r ) { Rearth = r; }
 
-    /**@short compute and set the distance from Earth, in AU.
+    /** @short compute and set the distance from Earth, in AU.
      * @param Earth pointer to the Earth from which to calculate the distance.
      */
     void setRearth( const KSPlanetBase *Earth );
@@ -151,7 +150,7 @@ public:
      */
     virtual void updateCoords( KSNumbers *num, bool includePlanets=true, const dms *lat=0, const dms *LST=0, bool forceRecompute = false );
 
-    /**@short Find position, including correction for Figure-of-the-Earth.
+    /** @short Find position, including correction for Figure-of-the-Earth.
      * @param num KSNumbers pointer for the target date/time
      * @param lat pointer to the geographic latitude; if NULL, we skip localizeCoords()
      * @param LST pointer to the local sidereal time; if NULL, we skip localizeCoords()
@@ -162,7 +161,7 @@ public:
     /** @return the Planet's position angle. */
     virtual double pa() const { return PositionAngle; }
 
-    /**@short Set the Planet's position angle.
+    /** @short Set the Planet's position angle.
      * @param p the new position angle
      */
     void setPA( double p ) { PositionAngle = p; }
@@ -170,7 +169,7 @@ public:
     /** @return the Planet's angular size, in arcminutes */
     double angSize() const { return AngularSize; }
 
-    /**@short set the planet's angular size, in km.
+    /** @short set the planet's angular size, in km.
      * @param size the planet's size, in km
      */
     void setAngularSize( double size ) { AngularSize = size; }
@@ -178,7 +177,7 @@ public:
     /** @return the Planet's physical size, in km */
     double physicalSize() const { return PhysicalSize; }
 
-    /**@short set the planet's physical size, in km.
+    /** @short set the planet's physical size, in km.
      * @param size the planet's size, in km
      */
     void setPhysicalSize( double size ) { PhysicalSize = size; }
@@ -208,8 +207,8 @@ protected:
 
     /** Compute high 32-bits of UID. */
     inline UID solarsysUID(UID type) const { return (SkyObject::UID_SOLARSYS << 60) | (type << 56); }
-   
-    /**@short find the object's current geocentric equatorial coordinates (RA and Dec)
+
+    /** @short find the object's current geocentric equatorial coordinates (RA and Dec)
      * This function is pure virtual; it must be overloaded by subclasses.
      * This function is private; it is called by the public function findPosition()
      * which also includes the figure-of-the-earth correction, localizeCoords().
@@ -219,7 +218,7 @@ protected:
      */
     virtual bool findGeocentricPosition( const KSNumbers *num, const KSPlanetBase *Earth=NULL ) = 0;
 
-    /** 
+    /**
      * @short Computes the visual magnitude for the major planets.
      * @param num pointer to a ksnumbers object. Needed for the saturn rings contribution to 
      *            saturn's magnitude.
