@@ -17,12 +17,14 @@
 
 #include "starobject.h"
 
+#include <typeinfo>
+
 #include <cmath>
 #include <QColor>
 #include <QPainter>
 #include <QFontMetricsF>
 #include <QPixmap>
-#include <kdebug.h>
+#include <QDebug>
 
 #include "kspopupmenu.h"
 #include "ksnumbers.h"
@@ -43,7 +45,7 @@
 //QVector<SkyPoint *> StarObject::Trail;
 // END DEBUG
 
-#include <cmath>
+#include <KLocalizedString>
 
 //----- Static Methods -----
 //
@@ -65,7 +67,7 @@ StarObject::StarObject( dms r, dms d, float m,
           PM_RA(pmra), PM_Dec(pmdec),
           Parallax(par), Multiplicity(mult), Variability(var)
 {
-    QByteArray spt = sptype.toAscii();
+    QByteArray spt = sptype.toLatin1();
     SpType[0] = spt[0];
     SpType[1] = spt[1];
     QString lname;
@@ -92,7 +94,7 @@ StarObject::StarObject( double r, double d, float m,
       PM_RA(pmra), PM_Dec(pmdec),
       Parallax(par), Multiplicity(mult), Variability(var)
 {
-    QByteArray spt = sptype.toAscii();
+    QByteArray spt = sptype.toLatin1();
     SpType[0] = spt[0];
     SpType[1] = spt[1];
 
@@ -128,6 +130,7 @@ StarObject::StarObject( const StarObject &o ) :
 
 StarObject* StarObject::clone() const
 {
+    Q_ASSERT( typeid( this ) == typeid( static_cast<const StarObject *>( this ) ) ); // Ensure we are not slicing a derived class
     return new StarObject(*this);
 }
 
@@ -162,7 +165,7 @@ void StarObject::init( const starData *stardata )
     testStar = false;
     if( stardata->HD == 103095 && Trail.size() == 0 ) {
       // Populate Trail with various positions
-        kDebug() << "TEST STAR FOUND!";
+        qDebug() << "TEST STAR FOUND!";
         testStar = true;
         KSNumbers num( J2000 ); // Some estimate, doesn't matter.
         long double jy;
@@ -172,7 +175,7 @@ void StarObject::init( const starData *stardata )
             getIndexCoords( &num, &ra, &dec );
             Trail.append( new SkyPoint( ra / 15.0, dec ) );
         }
-        kDebug() << "Populated the star's trail with " << Trail.size() << " entries.";
+        qDebug() << "Populated the star's trail with " << Trail.size() << " entries.";
     }
     */
     // END DEBUG.
@@ -359,32 +362,32 @@ QString StarObject::greekLetter( bool gchar ) const {
     QString letter = code;  //in case genitive name is *not* a Greek letter
     int alpha = 0x03B1;
 
-    if ( code == "alp" ) gchar ? letter = QString( QChar(alpha + 0) ) : letter = i18n("alpha");
-    if ( code == "bet" ) gchar ? letter = QString( QChar(alpha + 1) ) : letter = i18n("beta");
-    if ( code == "gam" ) gchar ? letter = QString( QChar(alpha + 2) ) : letter = i18n("gamma");
-    if ( code == "del" ) gchar ? letter = QString( QChar(alpha + 3) ) : letter = i18n("delta");
-    if ( code == "eps" ) gchar ? letter = QString( QChar(alpha + 4) ) : letter = i18n("epsilon");
-    if ( code == "zet" ) gchar ? letter = QString( QChar(alpha + 5) ) : letter = i18n("zeta");
-    if ( code == "eta" ) gchar ? letter = QString( QChar(alpha + 6) ) : letter = i18n("eta");
-    if ( code == "the" ) gchar ? letter = QString( QChar(alpha + 7) ) : letter = i18n("theta");
-    if ( code == "iot" ) gchar ? letter = QString( QChar(alpha + 8) ) : letter = i18n("iota");
-    if ( code == "kap" ) gchar ? letter = QString( QChar(alpha + 9) ) : letter = i18n("kappa");
-    if ( code == "lam" ) gchar ? letter = QString( QChar(alpha +10) ) : letter = i18n("lambda");
-    if ( code == "mu " ) gchar ? letter = QString( QChar(alpha +11) ) : letter = i18n("mu");
-    if ( code == "nu " ) gchar ? letter = QString( QChar(alpha +12) ) : letter = i18n("nu");
-    if ( code == "xi " ) gchar ? letter = QString( QChar(alpha +13) ) : letter = i18n("xi");
-    if ( code == "omi" ) gchar ? letter = QString( QChar(alpha +14) ) : letter = i18n("omicron");
-    if ( code == "pi " ) gchar ? letter = QString( QChar(alpha +15) ) : letter = i18n("pi");
-    if ( code == "rho" ) gchar ? letter = QString( QChar(alpha +16) ) : letter = i18n("rho");
+    if ( code == "alp" ) gchar ? letter = QString( QChar(alpha + 0) ) : letter = xi18n("alpha");
+    if ( code == "bet" ) gchar ? letter = QString( QChar(alpha + 1) ) : letter = xi18n("beta");
+    if ( code == "gam" ) gchar ? letter = QString( QChar(alpha + 2) ) : letter = xi18n("gamma");
+    if ( code == "del" ) gchar ? letter = QString( QChar(alpha + 3) ) : letter = xi18n("delta");
+    if ( code == "eps" ) gchar ? letter = QString( QChar(alpha + 4) ) : letter = xi18n("epsilon");
+    if ( code == "zet" ) gchar ? letter = QString( QChar(alpha + 5) ) : letter = xi18n("zeta");
+    if ( code == "eta" ) gchar ? letter = QString( QChar(alpha + 6) ) : letter = xi18n("eta");
+    if ( code == "the" ) gchar ? letter = QString( QChar(alpha + 7) ) : letter = xi18n("theta");
+    if ( code == "iot" ) gchar ? letter = QString( QChar(alpha + 8) ) : letter = xi18n("iota");
+    if ( code == "kap" ) gchar ? letter = QString( QChar(alpha + 9) ) : letter = xi18n("kappa");
+    if ( code == "lam" ) gchar ? letter = QString( QChar(alpha +10) ) : letter = xi18n("lambda");
+    if ( code == "mu " ) gchar ? letter = QString( QChar(alpha +11) ) : letter = xi18n("mu");
+    if ( code == "nu " ) gchar ? letter = QString( QChar(alpha +12) ) : letter = xi18n("nu");
+    if ( code == "xi " ) gchar ? letter = QString( QChar(alpha +13) ) : letter = xi18n("xi");
+    if ( code == "omi" ) gchar ? letter = QString( QChar(alpha +14) ) : letter = xi18n("omicron");
+    if ( code == "pi " ) gchar ? letter = QString( QChar(alpha +15) ) : letter = xi18n("pi");
+    if ( code == "rho" ) gchar ? letter = QString( QChar(alpha +16) ) : letter = xi18n("rho");
     //there are two unicode symbols for sigma;
     //skip the first one, the second is more widely used
-    if ( code == "sig" ) gchar ? letter = QString( QChar(alpha +18) ) : letter = i18n("sigma");
-    if ( code == "tau" ) gchar ? letter = QString( QChar(alpha +19) ) : letter = i18n("tau");
-    if ( code == "ups" ) gchar ? letter = QString( QChar(alpha +20) ) : letter = i18n("upsilon");
-    if ( code == "phi" ) gchar ? letter = QString( QChar(alpha +21) ) : letter = i18n("phi");
-    if ( code == "chi" ) gchar ? letter = QString( QChar(alpha +22) ) : letter = i18n("chi");
-    if ( code == "psi" ) gchar ? letter = QString( QChar(alpha +23) ) : letter = i18n("psi");
-    if ( code == "ome" ) gchar ? letter = QString( QChar(alpha +24) ) : letter = i18n("omega");
+    if ( code == "sig" ) gchar ? letter = QString( QChar(alpha +18) ) : letter = xi18n("sigma");
+    if ( code == "tau" ) gchar ? letter = QString( QChar(alpha +19) ) : letter = xi18n("tau");
+    if ( code == "ups" ) gchar ? letter = QString( QChar(alpha +20) ) : letter = xi18n("upsilon");
+    if ( code == "phi" ) gchar ? letter = QString( QChar(alpha +21) ) : letter = xi18n("phi");
+    if ( code == "chi" ) gchar ? letter = QString( QChar(alpha +22) ) : letter = xi18n("chi");
+    if ( code == "psi" ) gchar ? letter = QString( QChar(alpha +23) ) : letter = xi18n("psi");
+    if ( code == "ome" ) gchar ? letter = QString( QChar(alpha +24) ) : letter = xi18n("omega");
 
     if ( name2().length() && name2().mid(3,1) != " " )
         letter += '[' + name2().mid(3,1) + ']';
@@ -495,20 +498,20 @@ QString StarObject::nameLabel( bool drawName, bool drawMag ) const
 {
     QString sName;
     if ( drawName ) {
-        if ( translatedName() != i18n("star") && ! translatedName().isEmpty() )
+        if ( translatedName() != xi18n("star") && ! translatedName().isEmpty() )
             sName = translatedName();
         else if ( ! gname().trimmed().isEmpty() )
             sName = gname( true );
         else {
             if ( drawMag )
-                return KGlobal::locale()->formatNumber( mag(), 1 );
+                return QLocale().toString( mag(), 1 );
         }
         if ( ! drawMag )
             return sName;
         else
-            return sName + ' ' + KGlobal::locale()->formatNumber( mag(), 1 );
+            return sName + ' ' + QLocale().toString( mag(), 1 );
     }
-    return KGlobal::locale()->formatNumber( mag(), 1 );
+    return QLocale().toString( mag(), 1 );
 }
 
 //If this works, we can maybe get rid of customLabel() and nameLabel()??
