@@ -334,9 +334,9 @@ bool SkyQPainter::drawPlanet(KSPlanetBase* planet)
         // Draw them as bright stars of appropriate color instead of images
         char spType;
         //FIXME: do these need i18n?
-        if( planet->name() == i18n("Mars") ) {
+        if( planet->name() == xi18n("Mars") ) {
             spType = 'K';
-        } else if( planet->name() == i18n("Jupiter") || planet->name() == i18n("Mercury") || planet->name() == i18n("Saturn") ) {
+        } else if( planet->name() == xi18n("Jupiter") || planet->name() == xi18n("Mercury") || planet->name() == xi18n("Saturn") ) {
             spType = 'F';
         } else {
             spType = 'B';
@@ -354,6 +354,9 @@ bool SkyQPainter::drawPlanet(KSPlanetBase* planet)
             //Because Saturn has rings, we inflate its image size by a factor 2.5
             if( planet->name() == "Saturn" )
                 size = int(2.5*size);
+            // Scale size exponentially so it is visible at large zooms
+            else if (planet->name() == "Pluto")
+                size = int(size*exp(1.5*size));
 
             save();
             translate(pos);
@@ -800,12 +803,12 @@ bool SkyQPainter::drawSupernova(Supernova* sup)
 
     bool visible = false;
     QPointF pos = m_proj->toScreen(sup,true,&visible);
-    //kDebug()<<"sup->ra() = "<<(sup->ra()).toHMSString()<<"sup->dec() = "<<sup->dec().toDMSString();
-    //kDebug()<<"pos = "<<pos<<"m_proj->onScreen(pos) = "<<m_proj->onScreen(pos);
+    //qDebug()<<"sup->ra() = "<<(sup->ra()).toHMSString()<<"sup->dec() = "<<sup->dec().toDMSString();
+    //qDebug()<<"pos = "<<pos<<"m_proj->onScreen(pos) = "<<m_proj->onScreen(pos);
     if( !visible || !m_proj->onScreen(pos) ) return false;
 
     setPen( data->colorScheme()->colorNamed("SupernovaColor") );
-    //kDebug()<<"Here"<<endl;
+    //qDebug()<<"Here"<<endl;
     drawLine ( QPoint( pos.x () - 2.0, pos.y() ), QPoint( pos.x() + 2.0, pos.y() ) );
     drawLine ( QPoint( pos.x (), pos.y() - 2.0 ), QPoint( pos.x(), pos.y() + 2.0 ) );
     return true;
