@@ -17,9 +17,8 @@
 
 #include "eqplotwidget.h"
 #include <QPainter>
-#include <KGlobal>
-#include <KLocale>
-#include <kdebug.h>
+#include <KLocalizedString>
+#include <QDebug>
 #include "kstarsdatetime.h"
 #include "modcalcvizequinox.h"
 
@@ -52,29 +51,29 @@ void eqPlotWidget::paintEvent( QPaintEvent *e ) {
     p.save();
     p.translate( leftPadding() + pSpring.x(), topPadding() + pSpring.y() );
     p.rotate(-90);
-    p.drawText( 0, 0, i18n("Vernal equinox:") );
-    p.drawText( 0, 14, KGlobal::locale()->formatDateTime( mc->dSpring, KLocale::LongDate ) );
+    p.drawText( 0, 0, xi18n("Vernal equinox:") );
+    p.drawText( 0, 14, QLocale().toString( mc->dSpring, QLocale::LongFormat ) );
     p.restore();
 
     p.save();
     p.translate( leftPadding() + pSummer.x(), topPadding() + pSummer.y() );
     p.rotate(-90);
-    p.drawText( 0, 0, i18n("Summer solstice:") );
-    p.drawText( 0, 14, KGlobal::locale()->formatDateTime( mc->dSummer, KLocale::LongDate ) );
+    p.drawText( 0, 0, xi18n("Summer solstice:") );
+    p.drawText( 0, 14, QLocale().toString( mc->dSummer, QLocale::LongFormat ) );
     p.restore();
 
     p.save();
     p.translate( leftPadding() + pAutumn.x(), topPadding() + pAutumn.y() );
     p.rotate(-90);
-    p.drawText( 0, 0, i18n("Autumnal equinox:") );
-    p.drawText( 0, 14, KGlobal::locale()->formatDateTime( mc->dAutumn, KLocale::LongDate ) );
+    p.drawText( 0, 0, xi18n("Autumnal equinox:") );
+    p.drawText( 0, 14, QLocale().toString( mc->dAutumn, QLocale::LongFormat ) );
     p.restore();
 
     p.save();
     p.translate( leftPadding() + pWinter.x(), topPadding() + pWinter.y() );
     p.rotate(-90);
-    p.drawText( 0, 0, i18n("Winter solstice:") );
-    p.drawText( 0, 14, KGlobal::locale()->formatDateTime( mc->dWinter, KLocale::LongDate ) );
+    p.drawText( 0, 0, xi18n("Winter solstice:") );
+    p.drawText( 0, 14, QLocale().toString( mc->dWinter, QLocale::LongFormat ) );
     p.restore();
 
     //Draw month labels along top axis
@@ -97,4 +96,3 @@ void eqPlotWidget::paintEvent( QPaintEvent *e ) {
     p.end();
 }
 
-#include "eqplotwidget.moc"
