@@ -21,7 +21,7 @@
 #include <QList>
 #include <QAbstractTableModel>
 
-#include <kdialog.h>
+#include <QDialog>
 #include <kio/copyjob.h>
 
 #include "ui_observinglist.h"
@@ -42,31 +42,31 @@ class ObservingListUI : public QFrame, public Ui::ObservingList {
     Q_OBJECT
 
 public:
-    /**@short Cunstructor
+    /** @short Cunstructor
         */
     ObservingListUI( QWidget *parent );
 };
 
-/**@class ObservingList
+/** @class ObservingList
     *Tool window for managing a custom list of objects.  The window
     *displays the Name, RA, Dec, mag, and type of each object in the list.
     *
     *By selecting an object in the list, you can perform a number of functions
     *on that object:
-    *+ Center it in the display 
-    *+ Examine its Details Window 
-    *+ Point the telescope at it 
+    *+ Center it in the display
+    *+ Examine its Details Window
+    *+ Point the telescope at it
     *+ Attach a custom icon or name label (TBD)
     *+ Attach a trail (solar system only) (TBD)
-    *+ Open the AltVsTime tool 
+    *+ Open the AltVsTime tool
     *
-    *The user can also save/load their observing lists, and can export 
+    *The user can also save/load their observing lists, and can export
     *list data (TBD: as HTML table?  CSV format?  plain text?)
     *
-    *The observing notes associated with the selected object are displayed 
+    *The observing notes associated with the selected object are displayed
     *below the list.
     *
-    *TODO: 
+    *TODO:
     *+ Implement a "shaded" state, in which the UI is compressed to
     *  make it easier to float on the KStars window.  Displays only
     *  object names, and single-letter action buttons, and no user log.
@@ -77,81 +77,81 @@ public:
     *@version 1.0
     */
 
-class ObservingList : public KDialog
+class ObservingList : public QDialog
 {
     Q_OBJECT
 
 public:
-    /**@short Constructor
+    /** @short Constructor
         */
-    ObservingList( KStars *_ks );
-    /**@short Destuctor (empty)
+    ObservingList();
+    /** @short Destuctor (empty)
         */
     ~ObservingList();
 
-    /**@return true if the object is in the observing list
+    /** @return true if the object is in the observing list
         *@p o pointer to the object to test.
         */
-    inline bool contains( const SkyObject *o ) { return m_ObservingList.contains( const_cast<SkyObject*>(o) ); }
+    inline bool contains( const SkyObject *o ) { return m_WishList.contains( const_cast<SkyObject*>(o) ); }
 
-    /**@return true if the window is in its default "large" state.
+    /** @return true if the window is in its default "large" state.
         */
     bool isLarge() const { return bIsLarge; }
 
-    /**@return reference to the current observing list
+    /** @return reference to the current observing list
         */
-    QList<SkyObject*>& obsList() { return m_ObservingList; }
-    
-    /**@return reference to the current observing list
+    QList<SkyObject*>& obsList() { return m_WishList; }
+
+    /** @return reference to the current observing list
         */
     QList<SkyObject*>& sessionList() { return m_SessionList; }
 
-    /**@return pointer to the currently-selected object in the observing list
+    /** @return pointer to the currently-selected object in the observing list
         *@note if more than one object is selected, this function returns 0.
         */
     SkyObject *currentObject() const { return m_CurrentObject; }
 
-    /**@short If the current list has unsaved changes, ask the user about saving it.
+    /** @short If the current list has unsaved changes, ask the user about saving it.
         *@note also clears the list in preparation of opening a new one
         */
     void saveCurrentList();
 
-    /**@short Plot the SkyObject's Altitude vs Time in the AVTPlotWidget.
+    /** @short Plot the SkyObject's Altitude vs Time in the AVTPlotWidget.
        *@p o pointer to the object to be plotted
        */
     void plot( SkyObject *o );
 
-    /**@short Return the altitude of the given SkyObject for the given hour.
-        *@p p pointer to the SkyObject 
+    /** @short Return the altitude of the given SkyObject for the given hour.
+        *@p p pointer to the SkyObject
         *@p hour time at which altitude has to be found
         */
     double findAltitude( SkyPoint *p, double hour=0);
 
-    /**@short Return the list of downloaded images
+    /** @short Return the list of downloaded images
         */
     QList<QString> imageList() { return ImageList; }
 
-    /**@short Sets the image parameters for the current object
+    /** @short Sets the image parameters for the current object
         *@p o The passed object for setting the parameters
         *@p temp A flag to edit the name for temporary images
         */
     void setCurrentImage( const SkyObject *o, bool temp = false );
 
-    /**@short Save the user log text to a file.
+    /** @short Save the user log text to a file.
         *@note the log is attached to the current object in obsList.
         */
     void saveCurrentUserLog();
 
-    /**@short decides on whether to enable the SaveImages button or not
+    /** @short decides on whether to enable the SaveImages button or not
         */
     void setSaveImagesButton();
 
-    /**@short This is the declaration of the event filter function
+    /** @short This is the declaration of the event filter function
      * which is installed on the KImageFilePreview and the TabeView
      */
     bool eventFilter( QObject *obj, QEvent *event );
 
-    /**@short saves a thumbnail image for the details dialog
+    /** @short saves a thumbnail image for the details dialog
      * from the downloaded image
      */
     void saveThumbImage();
@@ -166,38 +166,38 @@ public:
 
     KStarsDateTime dateTime() { return dt; }
 
-    /**@short return the object with the name as the passed
+    /** @short return the object with the name as the passed
      * QString from the Session List, return null otherwise
      */
     SkyObject* findObjectByName( QString name );
 
-    /**@short make a selection in the session view 
+    /** @short make a selection in the session view
      */
     void selectObject( const SkyObject *o );
 
-    /**@short set the default image in the image preview.
+    /** @short set the default image in the image preview.
      */
     void setDefaultImage();
 
-    /**@short get object name. If star has no name, generate a name based on catalog number.
+    /** @short get object name. If star has no name, generate a name based on catalog number.
      * @param translated set to true if the translated name is required.
      */
     QString getObjectName(const SkyObject *o, bool translated=true);
 
 public slots:
-    /**@short add a new object to list
+    /** @short add a new object to list
         *@p o pointer to the object to add to the list
         *@p session flag toggle adding the object to the session list
         *@p update flag to toggle the call of slotSaveList
         */
     void slotAddObject( SkyObject *o=NULL, bool session=false, bool update=false );
 
-    /**@short Remove skyobjects which are highlighted in the
+    /** @short Remove skyobjects which are highlighted in the
         *observing list tool from the observing list.
         */
     void slotRemoveSelectedObjects();
 
-    /**@short Remove skyobject from the observing list.
+    /** @short Remove skyobject from the observing list.
         *@p o pointer to the SkyObject to be removed.
         *@p session flag to tell it whether to remove the object
         *from the sessionlist or from the wishlist
@@ -206,133 +206,133 @@ public slots:
         */
     void slotRemoveObject( SkyObject *o=NULL, bool session=false, bool update=false );
 
-    /**@short center the selected object in the display
+    /** @short center the selected object in the display
         */
     void slotCenterObject();
 
-    /**@short slew the telescope to the selected object
+    /** @short slew the telescope to the selected object
         */
     void slotSlewToObject();
 
-    /**@short Show the details window for the selected object
+    /** @short Show the details window for the selected object
         */
     void slotDetails();
 
-    /**@short Show the Altitude vs Time for selecteld objects
+    /** @short Show the Altitude vs Time for selecteld objects
         */
     void slotAVT();
 
-    /**@short Open the WUT dialog
+    /** @short Open the WUT dialog
     */
     void slotWUT();
 
-    /**@short Add the object to the Session List
+    /** @short Add the object to the Session List
         */
     void slotAddToSession();
 
-    /**@short Open the Find Dialog
+    /** @short Open the Find Dialog
         */
     void slotFind();
 
-    /**@short Tasks needed when changing the selected object
-        *Save the user log of the previous selected object, 
-        *find the new selected object in the obsList, and 
+    /** @short Tasks needed when changing the selected object
+        *Save the user log of the previous selected object,
+        *find the new selected object in the obsList, and
         *show the notes associated with the new selected object
         */
     void slotNewSelection();
 
-    /**@short load an observing list from disk.
+    /** @short load an observing list from disk.
         */
     void slotOpenList();
 
-    /**@short save the current observing list to disk.
+    /** @short save the current observing list to disk.
         */
     void slotSaveList();
 
-    /**@short Load the Wish list from disk.
+    /** @short Load the Wish list from disk.
         */
     void slotLoadWishList();
 
-    /**@short save the current observing session plan to disk, specify filename.
+    /** @short save the current observing session plan to disk, specify filename.
         */
     void slotSaveSessionAs(bool nativeSave = true);
 
-    /**@short save the current session
+    /** @short save the current session
         */
     void slotSaveSession(bool nativeSave = true);
 
-    /**@short construct a new observing list using the wizard.
+    /** @short construct a new observing list using the wizard.
         */
     void slotWizard();
 
-    /**@short toggle between the large and small window states
+    /** @short toggle between the large and small window states
         */
     void slotToggleSize();
 
-    /**@short toggle the setEnabled flags according to current view
+    /** @short toggle the setEnabled flags according to current view
         *set the m_currentItem to NULL and clear selections
         *@p index captures the integer value sent by the signal
         *which is the currentIndex of the table
         */
     void slotChangeTab(int index);
 
-    /**@short Opens the Location dialog to set the GeoLocation
+    /** @short Opens the Location dialog to set the GeoLocation
         *for the sessionlist.
         */
     void slotLocation();
 
-    /**@short Updates the tableviews for the new geolocation and date 
+    /** @short Updates the tableviews for the new geolocation and date
         */
     void slotUpdate();
 
-    /**@short Takes the time from the QTimeEdit box and sets it as the
+    /** @short Takes the time from the QTimeEdit box and sets it as the
         *time parameter in the tableview of the SessionList.
         */
     void slotSetTime();
 
-    /**@short Downloads the corresponding DSS or SDSS image from the web and
+    /** @short Downloads the corresponding DSS or SDSS image from the web and
         *displays it
         */
     void slotGetImage( bool _dss = false );
 
-    void slotGoogleImage();
+    void slotSearchImage();
 
-    /**@short Downloads the images of all the objects in the session list
+    /** @short Downloads the images of all the objects in the session list
         *Note: This downloads the SDSS image, checks if the size is > default image
         *and gets the DSS image if thats the case
         */
     void slotSaveAllImages();
 
-    /**@short saves the image syncronously from a given URL into a given file
+    /** @short saves the image syncronously from a given URL into a given file
         *@p url the url from which the image has to be downloaded
         *@p filename the file onto which the url has to be copied to
         *NOTE: This is not a generic image saver, it is specific to the current object
         */
-    void saveImage( KUrl url , QString filename );
+    void saveImage( QUrl url , QString filename );
 
-    /**@short saves the temporary image permanently
+    /** @short saves the temporary image permanently
         */
     void slotSaveImage();
 
-    /**@short Shows the image in a ImageViewer window.
+    /** @short Shows the image in a ImageViewer window.
         */
     void slotImageViewer();
 
-    /**@short Remove the current image
+    /** @short Remove the current image
         */
     void slotDeleteCurrentImage();
 
-    /**@short Removes all the save DSS/SDSS images from the disk.
+    /** @short Removes all the save DSS/SDSS images from the disk.
         */
     void slotDeleteAllImages();
 
-    /**@short download the DSS image and show it
+    /** @short download the DSS image and show it
         */
     void slotDSS() { slotGetImage( true ); }
 
-    /**@short Export a target list to the oal compliant format
+    /** @short Export a target list to the oal compliant format
         */
-    void slotOALExport(); 
+    void slotOALExport();
 
     void slotAddVisibleObj();
 
@@ -347,21 +347,51 @@ protected slots:
     void downloadReady();
 
 private:
-    KStars *ks;
+
+    /**
+     * @short Return the active list
+     * @return The session list or the wish list depending on which tab is currently being viewed.
+     */
+    inline QList<SkyObject *>& getActiveList() { return ( ( sessionView ) ? m_SessionList : m_WishList ); }
+
+    /**
+     * @short Return the active itemmodel
+     * @return the session model or the wishlist model depending on which tab is currently being viewed.
+     */
+    inline QStandardItemModel *getActiveModel() const { return ( ( sessionView ) ? m_SessionModel : m_WishListModel ); }
+
+    /**
+     * @short Return the active sort model
+     * @return the session sort model or the wishlist sort model depending on which tab is currently being viewed.
+     */
+    inline QSortFilterProxyModel *getActiveSortModel() const { return ( ( sessionView ) ? m_SessionSortModel : m_WishListSortModel ); }
+
+    /**
+     * @short Return the active view
+     * @return the active view in the UI -- session view or wishlist view depending on which one is active.
+     */
+    inline QTableView *getActiveView() const { return ( ( sessionView ) ? ( ui->SessionView ) : ( ui->TableView ) ); }
+
+    /**
+     * @short Get the currently selected item indexes
+     * @return a QModelIndexList containing the selected rows in the active QTableView
+     */
+    inline QModelIndexList getSelectedItems() const { return getActiveView()->selectionModel()->selectedRows(); }
+
     KSAlmanac *ksal;
     ObservingListUI *ui;
-    QList<SkyObject*> m_ObservingList, m_SessionList;
+    QList<SkyObject*> m_WishList, m_SessionList;
     SkyObject *LogObject, *m_CurrentObject;
     bool isModified, bIsLarge, sessionView, dss, singleSelection, showScope, noSelection;
     QString FileName, CurrentImage, DSSUrl, SDSSUrl, ThumbImage, CurrentImagePath, CurrentTempPath;
     KStarsDateTime dt;
     GeoLocation *geo;
-    QStandardItemModel *m_Model, *m_Session;
-    QSortFilterProxyModel *m_SortModel, *m_SortModelSession;
+    QStandardItemModel *m_WishListModel, *m_SessionModel;
+    QSortFilterProxyModel *m_WishListSortModel, *m_SessionSortModel;
     KIO::Job *downloadJob;  // download job of image -> 0 == no job is running
-    QHash<QString, QTime> TimeHash; 
+    QHash<QString, QTime> TimeHash;
     QList<QString> ImageList;
-    ObsListPopupMenu *pmenu; 
+    ObsListPopupMenu *pmenu;
     EyepieceField *m_epf;
 };
 
