@@ -19,15 +19,15 @@
 
 #include <cstdlib>
 
-#include <kdebug.h>
-#include <klocale.h>
+#include <QDebug>
+#include <KLocalizedString>
 
 #include <QRegExp>
 #include <QFocusEvent>
 #include <QApplication>
 
 dmsBox::dmsBox(QWidget *parent, bool dg)
-        : KLineEdit(parent), EmptyFlag(true) {
+        : QLineEdit(parent), EmptyFlag(true) {
     setMaxLength(14);
     setMaximumWidth(160);
     setDegType( dg );
@@ -58,7 +58,7 @@ void dmsBox::setEmptyText() {
 }
 
 void dmsBox::focusInEvent( QFocusEvent *e ) {
-    KLineEdit::focusInEvent( e );
+    QLineEdit::focusInEvent( e );
 
     if ( EmptyFlag ) {
         clear();
@@ -68,7 +68,7 @@ void dmsBox::focusInEvent( QFocusEvent *e ) {
 }
 
 void dmsBox::focusOutEvent( QFocusEvent *e ) {
-    KLineEdit::focusOutEvent( e );
+    QLineEdit::focusOutEvent( e );
 
     if ( text().isEmpty() ) {
         setEmptyText();
@@ -90,38 +90,38 @@ void dmsBox::slotTextChanged( const QString &t ) {
 void dmsBox::setDegType( bool t ) {
     deg = t;
 
-    QString sTip = ( t ? i18n( "Angle value in degrees." ) : i18n( "Angle value in hours." ) );
+    QString sTip = ( t ? xi18n( "Angle value in degrees." ) : xi18n( "Angle value in hours." ) );
     QString sWhatsThis;
 
     if ( isReadOnly() ) {
         if( t ) {
-            sWhatsThis = i18n( "This box displays an angle in degrees. "
+            sWhatsThis = xi18n( "This box displays an angle in degrees. "
                                "The three numbers displayed are the angle's "
                                "degrees, arcminutes, and arcseconds." );
         }
         else {
-            sWhatsThis = i18n( "This box displays an angle in hours. "
+            sWhatsThis = xi18n( "This box displays an angle in hours. "
                                "The three numbers displayed are the angle's "
                                "hours, minutes, and seconds." );
         }
     } else {
         if( t ) {
-            sTip += i18n( "  You may enter a simple integer, or a floating-point value, "
+            sTip += xi18n( "  You may enter a simple integer, or a floating-point value, "
                           "or space- or colon-delimited values specifying "
                           "degrees, arcminutes and arcseconds" );
 
-            sWhatsThis = i18n( "Enter an angle value in degrees.  The angle can be expressed "
+            sWhatsThis = xi18n( "Enter an angle value in degrees.  The angle can be expressed "
                                "as a simple integer (\"12\"), a floating-point value "
                                "(\"12.33\"), or as space- or colon-delimited "
                                "values specifying degrees, arcminutes and arcseconds (\"12:20\", \"12:20:00\", "
                                "\"12 20\", \"12 20 00.0\", etc.)." );
         }
         else {
-            sTip += i18n( "  You may enter a simple integer, or a floating-point value, "
+            sTip += xi18n( "  You may enter a simple integer, or a floating-point value, "
                           "or space- or colon-delimited values specifying "
                           "hours, minutes and seconds" );
 
-            sWhatsThis = i18n( "Enter an angle value in hours.  The angle can be expressed "
+            sWhatsThis = xi18n( "Enter an angle value in hours.  The angle can be expressed "
                                "as a simple integer (\"12\"), a floating-point value "
                                "(\"12.33\"), or as space- or colon-delimited "
                                "values specifying hours, minutes and seconds (\"12:20\", \"12:20:00\", "
@@ -173,4 +173,4 @@ dms dmsBox::createDms ( bool deg, bool *ok )
 dmsBox::~dmsBox(){
 }
 
-#include "dmsbox.moc"
+
